@@ -53,6 +53,7 @@ import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.Date;
 import java.util.List;
 import java.util.TimeZone;
@@ -121,9 +122,13 @@ public final class AllAction extends AppointmentAction {
         final Date start = req.applyTimeZone2Date(startUTC.getTime());
         final Date end = req.applyTimeZone2Date(endUTC.getTime());
         final int folderId = req.getFolderId();
-        final int orderBy = req.optInt(AJAXServlet.PARAMETER_SORT);
+        int orderBy = req.optInt(AJAXServlet.PARAMETER_SORT);
         final boolean showPrivateAppointments = Boolean.parseBoolean(req.getParameter(AJAXServlet.PARAMETER_SHOW_PRIVATE_APPOINTMENTS));
         final boolean listOrder;
+        
+        if (orderBy == AppointmentAJAXRequest.NOT_FOUND) {
+            orderBy = CalendarObject.START_DATE;
+        }
         if (orderBy == CalendarObject.START_DATE || orderBy == CalendarObject.END_DATE) {
             listOrder = true;
         } else {
