@@ -52,6 +52,8 @@ package com.openexchange.calendar.itip.generators;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 import com.openexchange.calendar.itip.generators.changes.PassthroughWrapper;
 import com.openexchange.groupware.container.participants.ConfirmStatus;
 import com.openexchange.i18n.tools.StringHelper;
@@ -111,7 +113,27 @@ public class Sentence {
         }
 
         String localized = sh.getString(message);
-        return String.format(localized, wrapped.toArray(new Object[wrapped.size()]));
+        return String.format(saneFormatString(localized), wrapped.toArray(new Object[wrapped.size()]));
+    }
+
+    private static final Pattern SANE_FORMAT = Pattern.compile("(%[0-9]+)?" + Pattern.quote("$") + "(\\s|$)");
+    private static String saneFormatString(final String format) {
+        if (isEmpty(format) || format.indexOf('$') < 0) {
+            return format;
+        }
+        return SANE_FORMAT.matcher(format).replaceAll("$1" + Matcher.quoteReplacement("$s") + "$2");
+    }
+
+    private static boolean isEmpty(final String string) {
+        if (null == string) {
+            return true;
+        }
+        final int len = string.length();
+        boolean isWhitespace = true;
+        for (int i = 0; isWhitespace && i < len; i++) {
+            isWhitespace = Character.isWhitespace(string.charAt(i));
+        }
+        return isWhitespace;
     }
     
     public String getMessage(Locale locale) {
