@@ -52,8 +52,6 @@ package com.openexchange.contacts.json.actions;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
-import java.util.TimeZone;
-
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.contacts.json.ContactRequest;
 import com.openexchange.documentation.RequestMethod;
@@ -61,13 +59,10 @@ import com.openexchange.documentation.Type;
 import com.openexchange.documentation.annotations.Action;
 import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.helpers.ContactField;
 import com.openexchange.groupware.container.Contact;
-import com.openexchange.groupware.search.Order;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.session.ServerSession;
 
 
 /**
@@ -91,56 +86,12 @@ public class AllAction extends ContactAction {
      * Initializes a new {@link AllAction}.
      * @param serviceLookup
      */
-    public AllAction(final ServiceLookup serviceLookup) {
+    public AllAction(ServiceLookup serviceLookup) {
         super(serviceLookup);
     }
 
     @Override
-    protected AJAXRequestResult perform(final ContactRequest req) throws OXException {
-        final ServerSession session = req.getSession();
-        final TimeZone timeZone = req.getTimeZone();
-        final int folder = req.getFolder();
-        final int[] columns = req.getColumns();
-        final int sort = req.getSort();
-        final Order order = req.getOrder();
-        final String collation = req.getCollation();
-        final int leftHandLimit = req.getLeftHandLimit();
-        int rightHandLimit = req.getRightHandLimit();
-        if (rightHandLimit == 0) {
-            rightHandLimit = 50000;
-        }
-
-        Date timestamp = new Date(0);
-        final ContactInterface contactInterface = getContactInterfaceDiscoveryService().newContactInterface(folder, session);
-        SearchIterator<Contact> it = null;
-        final List<Contact> contacts = new ArrayList<Contact>();
-        try {
-            it = contactInterface.getContactsInFolder(folder, leftHandLimit, rightHandLimit, sort, order, collation, columns);
-
-            while (it.hasNext()) {
-                final Contact contact = it.next();
-                final Date lastModified = contact.getLastModified();
-
-                // Correct last modified and creation date with users timezone
-                contact.setLastModified(getCorrectedTime(contact.getLastModified(), timeZone));
-                contact.setCreationDate(getCorrectedTime(contact.getCreationDate(), timeZone));
-                contacts.add(contact);
-
-                if (lastModified != null && timestamp.before(lastModified)) {
-                    timestamp = lastModified;
-                }
-            }
-        } finally {
-            if (it != null) {
-                it.close();
-            }
-        }
-
-        return new AJAXRequestResult(contacts, timestamp, "contact");
-    }
-    
-    @Override
-    protected AJAXRequestResult perform2(final ContactRequest request) throws OXException {
+    protected AJAXRequestResult perform(ContactRequest request) throws OXException {
         List<Contact> contacts = new ArrayList<Contact>();
         Date lastModified = new Date(0);
         SearchIterator<Contact> searchIterator = null;
