@@ -50,18 +50,18 @@
 package com.openexchange.contacts.json.actions;
 
 import java.util.Date;
-import org.json.JSONArray;
-import org.json.JSONException;
+import java.util.List;
+import java.util.Map;
+import java.util.Map.Entry;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
+import com.openexchange.contact.ContactService;
 import com.openexchange.contacts.json.ContactRequest;
 import com.openexchange.documentation.RequestMethod;
 import com.openexchange.documentation.annotations.Action;
 import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.server.ServiceLookup;
-import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 
 
@@ -85,62 +85,25 @@ public class DeleteAction extends ContactAction {
     public DeleteAction(final ServiceLookup serviceLookup) {
         super(serviceLookup);
     }
-
-    @Override
-    protected AJAXRequestResult perform(final ContactRequest req) throws OXException {
-        final ServerSession session = req.getSession();
-        final long timestamp = req.getTimestamp();
-        final Date date = new Date(timestamp);
-        if (req.getData() instanceof JSONObject) {
-            final int[] deleteRequestData = req.getDeleteRequestData();
-            final ContactInterface contactInterface = getContactInterfaceDiscoveryService().newContactInterface(
-                deleteRequestData[1],
-                session);
-            contactInterface.deleteContactObject(deleteRequestData[0], deleteRequestData[1], date);
-        } else {
-            JSONArray jsonArray = (JSONArray) req.getData();
-            for (int i = 0; i < jsonArray.length(); i++) {
-                try {
-                    JSONObject json = jsonArray.getJSONObject(i);
-                    final int id = json.getInt("id");
-                    final int folder = json.getInt("folder");
-                    final ContactInterface contactInterface = getContactInterfaceDiscoveryService().newContactInterface(
-                        folder,
-                        session);
-                    contactInterface.deleteContactObject(id, folder, date);
-                } catch (JSONException e) {
-                    throw AjaxExceptionCodes.JSON_ERROR.create(e);
-                }
-            }
-        }
-        final JSONObject response = new JSONObject();
-        return new AJAXRequestResult(response, date, "json");
-    }
     
     @Override
-    protected AJAXRequestResult perform2(final ContactRequest req) throws OXException {
-        final ServerSession session = req.getSession();
-        final long timestamp = req.getTimestamp();
-        final Date date = new Date(timestamp);
-        
-        if (req.getData() instanceof JSONObject) {
-            final int[] deleteRequestData = req.getDeleteRequestData();
-            getContactService().deleteContact(session, Integer.toString(deleteRequestData[1]), Integer.toString(deleteRequestData[0]), date);
+    protected AJAXRequestResult perform(ContactRequest request) throws OXException {
+        ServerSession session = request.getSession();
+        Date lastRead = new Date(request.getTimestamp());
+        if (request.getData() instanceof JSONObject) {
+            int[] deleteRequestData = request.getDeleteRequestData();
+            getContactService().deleteContact(session, Integer.toString(deleteRequestData[1]), Integer.toString(deleteRequestData[0]), lastRead);
         } else {
-            JSONArray jsonArray = (JSONArray) req.getData();
-            for (int i = 0; i < jsonArray.length(); i++) {
-                try {
-                    JSONObject json = jsonArray.getJSONObject(i);
-                    final int id = json.getInt("id");
-                    final int folder = json.getInt("folder");
-                    getContactService().deleteContact(session, String.valueOf(folder), String.valueOf(id), date);
-                } catch (JSONException e) {
-                    throw AjaxExceptionCodes.JSON_ERROR.create(e);
+            Map<String, List<String>> objectIDsPerFolder = request.getObjectIDsPerFolder();
+            if (null != objectIDsPerFolder && 0 < objectIDsPerFolder.size()) {
+                ContactService contactService = getContactService();
+                for (Entry<String, List<String>> entry : objectIDsPerFolder.entrySet()) {
+                    String[] objectIDs = entry.getValue().toArray(new String[entry.getValue().size()]);
+                    contactService.deleteContacts(session, entry.getKey(), objectIDs, lastRead);
                 }
             }
         }
-        final JSONObject response = new JSONObject();
-        return new AJAXRequestResult(response, date, "json");
+        return new AJAXRequestResult(new JSONObject(), lastRead, "json");
     }
-
+    
 }
