@@ -55,19 +55,15 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.TimeZone;
-
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.contacts.json.ContactRequest;
 import com.openexchange.documentation.RequestMethod;
 import com.openexchange.documentation.annotations.Action;
 import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.session.ServerSession;
 
 /**
  * {@link ListAction}
@@ -84,105 +80,19 @@ public class ListAction extends ContactAction {
      * 
      * @param serviceLookup
      */
-    public ListAction(final ServiceLookup serviceLookup) {
+    public ListAction(ServiceLookup serviceLookup) {
         super(serviceLookup);
     }
 
     @Override
-    protected AJAXRequestResult perform(final ContactRequest req) throws OXException {
-        final ServerSession session = req.getSession();
-        final int[] columns = req.getColumns();
-        final int[][] objectIdsAndFolderIds = req.getListRequestData();
-        final TimeZone timeZone = req.getTimeZone();
-
-        boolean allInSameFolder = true;
-        int lastFolder = -1;
-        for (final int[] objectIdAndFolderId : objectIdsAndFolderIds) {
-            final int folder = objectIdAndFolderId[1];
-            if (lastFolder != -1 && folder != lastFolder) {
-                allInSameFolder = false;
-            }
-            lastFolder = folder;
-        }
-
-        Date timestamp = new Date(0);
-        Date lastModified = null;
-        SearchIterator<Contact> it = null;
-
-        final List<Contact> sortedContacts;
-        try {
-            final List<Contact> contacts = new ArrayList<Contact>();
-            if (allInSameFolder) {
-                final ContactInterface contactInterface = getContactInterfaceDiscoveryService().newContactInterface(lastFolder, session);
-                it = contactInterface.getObjectsById(objectIdsAndFolderIds, columns);
-
-                while (it.hasNext()) {
-                    final Contact contact = it.next();
-                    contacts.add(contact);
-
-                    lastModified = contact.getLastModified();
-                    // Correct last modified and creation date with users timezone
-                    contact.setLastModified(getCorrectedTime(contact.getLastModified(), timeZone));
-                    contact.setCreationDate(getCorrectedTime(contact.getCreationDate(), timeZone));
-
-                    if (lastModified != null && timestamp.before(lastModified)) {
-                        timestamp = lastModified;
-                    }
-                }
-            } else {
-                for (final int[] objectIdAndFolderId : objectIdsAndFolderIds) {
-                    final int folder = objectIdAndFolderId[1];
-                    final ContactInterface contactInterface = getContactInterfaceDiscoveryService().newContactInterface(folder, session);
-                    it = contactInterface.getObjectsById(new int[][] { objectIdAndFolderId }, columns);
-
-                    while (it.hasNext()) {
-                        final Contact contact = it.next();
-                        lastModified = contact.getLastModified();
-
-                        // Correct last modified and creation date with users timezone
-                        contact.setLastModified(getCorrectedTime(contact.getLastModified(), timeZone));
-                        contact.setCreationDate(getCorrectedTime(contact.getCreationDate(), timeZone));
-                        contacts.add(contact);
-                    }
-
-                    if ((lastModified != null) && (timestamp.getTime() < lastModified.getTime())) {
-                        timestamp = lastModified;
-                    }
-                }
-            }
-
-            // Sort loaded contacts in the order they were requested
-            sortedContacts = new ArrayList<Contact>(contacts.size());
-            for (int i = 0; i < objectIdsAndFolderIds.length; i++) {
-                final int[] objectIdsAndFolderId = objectIdsAndFolderIds[i];
-                final int objectId = objectIdsAndFolderId[0];
-                final int folderId = objectIdsAndFolderId[1];
-
-                for (final Contact contact : contacts) {
-                    if (contact.getObjectID() == objectId && contact.getParentFolderID() == folderId) {
-                        sortedContacts.add(contact);
-                        break;
-                    }
-                }
-            }
-        } finally {
-            if (it != null) {
-                it.close();
-            }
-        }
-
-        return new AJAXRequestResult(sortedContacts, timestamp, "contact");
-    }
-    
-    @Override
-    protected AJAXRequestResult perform2(final ContactRequest request) throws OXException {
+    protected AJAXRequestResult perform(final ContactRequest request) throws OXException {
         /*
          * get requested object and folder IDs
          */
-        final int[][] objectIdsAndFolderIds = request.getListRequestData();
-        final Map<String, List<String>> ids = new HashMap<String, List<String>>();
-        for (final int[] objectIdAndFolderId : objectIdsAndFolderIds) {
-            final String folderID = Integer.toString(objectIdAndFolderId[1]);
+        int[][] objectIdsAndFolderIds = request.getListRequestData();
+        Map<String, List<String>> ids = new HashMap<String, List<String>>();
+        for (int[] objectIdAndFolderId : objectIdsAndFolderIds) {
+            String folderID = Integer.toString(objectIdAndFolderId[1]);
             if (false == ids.containsKey(folderID)) {
             	ids.put(folderID, new ArrayList<String>());
             }
@@ -191,16 +101,16 @@ public class ListAction extends ContactAction {
         /*
          * get contacts
          */
-        final List<Contact> contacts = new ArrayList<Contact>();
+        List<Contact> contacts = new ArrayList<Contact>();
         Date lastModified = new Date(0);
         for (final Entry<String, List<String>> entry : ids.entrySet()) {
             SearchIterator<Contact> searchIterator = null;
             try {
                 searchIterator = getContactService().getContacts(request.getSession(), entry.getKey(), 
                 		entry.getValue().toArray(new String[entry.getValue().size()]), request.getFields());
-                final int parentFolderID = Integer.parseInt(entry.getKey());
+                int parentFolderID = Integer.parseInt(entry.getKey());
                 while (searchIterator.hasNext()) {
-                    final Contact contact = searchIterator.next();
+                    Contact contact = searchIterator.next();
                     contact.setParentFolderID(parentFolderID);
                     lastModified = getLatestModified(lastModified, contact);
                     contacts.add(contact);
@@ -215,10 +125,10 @@ public class ListAction extends ContactAction {
             /*
              * sort loaded contacts in the order they were requested
              */
-            final List<Contact> sortedContacts = new ArrayList<Contact>(contacts.size());
+            List<Contact> sortedContacts = new ArrayList<Contact>(contacts.size());
             for (int i = 0; i < objectIdsAndFolderIds.length; i++) {
-                final int[] objectIdsAndFolderId = objectIdsAndFolderIds[i];
-                for (final Contact contact : contacts) {
+                int[] objectIdsAndFolderId = objectIdsAndFolderIds[i];
+                for (Contact contact : contacts) {
                     if (contact.getObjectID() == objectIdsAndFolderId[0] && contact.getParentFolderID() == objectIdsAndFolderId[1]) {
                         sortedContacts.add(contact);
                         break;
