@@ -68,16 +68,6 @@ public class InfostoreFileStorageActivator extends HousekeepingActivator {
         return new Class<?>[]{InfostoreFacade.class, InfostoreSearchEngine.class};
     }
 
-    @Override
-    protected void handleAvailability(final Class<?> clazz) {
-        // Don't care
-    }
-
-    @Override
-    protected void handleUnavailability(final Class<?> clazz) {
-        // Don't care
-    }
-
     @Override
     protected void startBundle() throws Exception {
         registerService(FileStorageService.class, new InfostoreFileStorageService() {
@@ -93,9 +83,4 @@ public class InfostoreFileStorageActivator extends HousekeepingActivator {
         }, null);
     }
 
-    @Override
-    protected void stopBundle() throws Exception {
-        cleanUp();
-    }
-
 }
