@@ -81,7 +81,7 @@ import com.openexchange.server.ServiceLookup;
  */
 public abstract class DeferredActivator implements BundleActivator, ServiceLookup {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(DeferredActivator.class);
+    static final Log LOG = com.openexchange.log.Log.loggerFor(DeferredActivator.class);
 
     private static final DeferredActivatorServiceStateLookup STATE_LOOKUP = new DeferredActivatorServiceStateLookup();
 
@@ -251,7 +251,7 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
             services = new ConcurrentHashMap<Class<?>, ServiceProvider<?>>(1);
             neededServiceTrackers = new ServiceTracker[0];
             availability = allAvailable = 0;
-            startBundle();
+            startUp(false);
         } else {
             final int len = classes.length;
             if (len > 0 && new HashSet<Class<?>>(Arrays.asList(classes)).size() != len) {
@@ -275,7 +275,7 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
                 }
             }
             if (len == 0) {
-                startBundle();
+                startUp(false);
             }
         }
     }
@@ -306,7 +306,7 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
     /**
      * Updates this bundles service state entry
      */
-    final void updateServiceState() {
+    protected final void updateServiceState() {
         if (null == context) {
             return;
         }
@@ -338,7 +338,7 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
      * @param index The class' index
      * @param clazz The service's class
      */
-    final void signalAvailability(final int index, final Class<?> clazz) {
+    protected final void signalAvailability(final int index, final Class<?> clazz) {
         availability |= (1 << index);
         if (started.get()) {
             /*
@@ -351,12 +351,13 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
                  * Start bundle
                  */
                 try {
-                    startBundle();
+                    startUp(false);
                     started.set(true);
                 } catch (final Exception e) {
                     final Bundle bundle = context.getBundle();
                     final StringBuilder errorBuilder = new StringBuilder(64);
-                    if (LOG.isErrorEnabled()) {
+                    final boolean errorEnabled = LOG.isErrorEnabled();
+                    if (errorEnabled) {
                         errorBuilder.append("\nStart-up of bundle \"").append(bundle.getSymbolicName()).append("\" failed: ");
                         final String errorMsg = e.getMessage();
                         if (null == errorMsg || "null".equals(errorMsg)) {
@@ -378,11 +379,11 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
 
                             @Override
                             public void run() {
-                                shutDownBundle(bundle, errorBuilder);
+                                shutDownBundle(bundle, errorEnabled ? errorBuilder : null);
                             }
                         }).start();
                     } else {
-                        shutDownBundle(bundle, errorBuilder);
+                        shutDownBundle(bundle, errorEnabled ? errorBuilder : null);
                     }
                 }
             }
@@ -395,18 +396,18 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
      * @param bundle The bundle to shut-down
      * @param errorBuilder The error string builder
      */
-    static void shutDownBundle(final Bundle bundle, final StringBuilder errorBuilder) {
+    protected static void shutDownBundle(final Bundle bundle, final StringBuilder errorBuilder) {
         try {
             /*
              * Stop with Bundle.STOP_TRANSIENT set to zero
              */
             bundle.stop();
-            if (LOG.isErrorEnabled()) {
+            if (null != errorBuilder) {
                 errorBuilder.setLength(0);
                 LOG.error(errorBuilder.append("\n\nBundle \"").append(bundle.getSymbolicName()).append("\" stopped.\n"));
             }
         } catch (final BundleException e) {
-            if (LOG.isErrorEnabled()) {
+            if (null != errorBuilder) {
                 errorBuilder.setLength(0);
                 LOG.error(errorBuilder.append("\n\nBundle \"").append(bundle.getSymbolicName()).append("\" could not be stopped.\n"));
             }
@@ -438,6 +439,26 @@ public abstract class DeferredActivator implements BundleActivator, ServiceLooku
         }
     }
 
+    private void startUp(final boolean async) throws Exception {
+        if (async) {
+            final Runnable task = new Runnable() {
+
+                @Override
+                public void run() {
+                    try {
+                        startBundle();
+                    } catch (final Throwable t) {
+                        ExceptionUtils.handleThrowable(t);
+                        LOG.error(t.getMessage(), t);
+                    }
+                }
+            };
+            new Thread(task).run();
+        } else {
+            startBundle();
+        }
+    }
+
     /**
      * Called when this bundle is started; meaning all needed services are available. So the framework can perform the bundle-specific
      * activities necessary to start this bundle. This method can be used to register services or to allocate any resources that this bundle
