@@ -63,7 +63,6 @@ import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -92,6 +91,8 @@ import com.openexchange.groupware.upload.impl.UploadSizeExceededException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.json.OXJSONWriter;
+import com.openexchange.log.LogFactory;
+import com.openexchange.session.Session;
 import com.openexchange.tools.UnsynchronizedStringWriter;
 import com.openexchange.tools.encoding.Helper;
 import com.openexchange.tools.exceptions.OXAborted;
@@ -147,7 +148,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = ServerSessionAdapter.valueOf(getSessionObject(req));
         } catch (final OXException e) {
-            handle(res, e, action);
+            handle(res, e, action, getSessionObject(req));
             return;
         }
 
@@ -161,16 +162,16 @@ public class Attachment extends PermissionServlet {
             try {
                 require(req, PARAMETER_FOLDERID, PARAMETER_ATTACHEDID, PARAMETER_MODULE, PARAMETER_ID);
             } catch (final OXException e) {
-                handle(res, e, action);
+                handle(res, e, action, session);
                 return;
             }
             int folderId, attachedId, moduleId, id;
             final String contentType = req.getParameter(PARAMETER_CONTENT_TYPE);
             try {
-                folderId = requireNumber(req, res, action, PARAMETER_FOLDERID);
-                attachedId = requireNumber(req, res, action, PARAMETER_ATTACHEDID);
-                moduleId = requireNumber(req, res, action, PARAMETER_MODULE);
-                id = requireNumber(req, res, action, PARAMETER_ID);
+                folderId = requireNumber(req, res, action, PARAMETER_FOLDERID, session);
+                attachedId = requireNumber(req, res, action, PARAMETER_ATTACHEDID, session);
+                moduleId = requireNumber(req, res, action, PARAMETER_MODULE, session);
+                id = requireNumber(req, res, action, PARAMETER_ID, session);
 
             } catch (final OXAborted x) {
                 return;
@@ -187,7 +188,8 @@ public class Attachment extends PermissionServlet {
                 contentType,
                 ctx,
                 user,
-                userConfig);
+                userConfig,
+                session);
         } else {
             final OXJSONWriter writer = new OXJSONWriter();
             final AttachmentRequest attRequest = new AttachmentRequest(session, writer);
@@ -210,12 +212,12 @@ public class Attachment extends PermissionServlet {
         }
     }
 
-    private int requireNumber(final HttpServletRequest req, final HttpServletResponse res, final String action, final String parameter) {
+    private int requireNumber(final HttpServletRequest req, final HttpServletResponse res, final String action, final String parameter, final Session session) {
         final String value = req.getParameter(parameter);
         try {
             return Integer.parseInt(value);
         } catch (final NumberFormatException nfe) {
-            handle(res, AttachmentExceptionCodes.INVALID_REQUEST_PARAMETER.create(parameter, value), action);
+            handle(res, AttachmentExceptionCodes.INVALID_REQUEST_PARAMETER.create(parameter, value), action, session);
             throw new OXAborted();
         }
     }
@@ -233,7 +235,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = ServerSessionAdapter.valueOf(getSessionObject(req));
         } catch (final OXException e) {
-            handle(res, e, action);
+            handle(res, e, action, getSessionObject(req));
             return;
         }
 
@@ -272,7 +274,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = ServerSessionAdapter.valueOf(getSessionObject(req));
         } catch (final OXException e) {
-            handle(res, e, action);
+            handle(res, e, action, getSessionObject(req));
             return;
         }
 
@@ -363,7 +365,7 @@ public class Attachment extends PermissionServlet {
 
     }
 
-    private void document(final HttpServletResponse res, final String userAgent, final boolean ie, final int folderId, final int attachedId, final int moduleId, final int id, final String contentType, final Context ctx, final User user, final UserConfiguration userConfig) {
+    private void document(final HttpServletResponse res, final String userAgent, final boolean ie, final int folderId, final int attachedId, final int moduleId, final int id, final String contentType, final Context ctx, final User user, final UserConfiguration userConfig, final Session session) {
         InputStream documentData = null;
         OutputStream os = null;
 
@@ -416,7 +418,7 @@ public class Attachment extends PermissionServlet {
             // in a new window. To call the JS callback routine from a popup we
             // can use parent.callback_error() but
             // must use window.opener.callback_error()
-            rollback(t, res, ResponseFields.ERROR);
+            rollback(t, res, ResponseFields.ERROR, session);
             return;
         } finally {
             if (documentData != null) {
@@ -444,16 +446,16 @@ public class Attachment extends PermissionServlet {
         }
     }
 
-    private void rollback(final Throwable t, final HttpServletResponse res, final String action) {
+    private void rollback(final Throwable t, final HttpServletResponse res, final String action, final Session session) {
         try {
             ATTACHMENT_BASE.rollback();
         } catch (final OXException e) {
             LOG.debug("", e);
         }
         if (t instanceof OXException) {
-            handle(res, (OXException) t, action);
+            handle(res, (OXException) t, action, session);
         } else {
-            handle(res, new OXException(t), action);
+            handle(res, new OXException(t), action, session);
         }
     }
 
@@ -496,7 +498,7 @@ public class Attachment extends PermissionServlet {
             } catch (final OXException e) {
                 LOG.error(e);
             }
-            handle(res, t, ResponseFields.ERROR);
+            handle(res, t, ResponseFields.ERROR, session);
             return;
         } catch (final JSONException e) {
             try {
@@ -504,7 +506,7 @@ public class Attachment extends PermissionServlet {
             } catch (final OXException x) {
                 LOG.error(e);
             }
-            handle(res, new OXException(e), ResponseFields.ERROR);
+            handle(res, new OXException(e), ResponseFields.ERROR, session);
             return;
         } catch (final IOException e) {
             try {
@@ -512,7 +514,7 @@ public class Attachment extends PermissionServlet {
             } catch (final OXException x) {
                 LOG.error(e);
             }
-            handle(res, new OXException(e), ResponseFields.ERROR);
+            handle(res, new OXException(e), ResponseFields.ERROR, session);
             return;
         } finally {
             try {
@@ -557,7 +559,7 @@ public class Attachment extends PermissionServlet {
         }
     }
 
-    private void handle(final HttpServletResponse res, final OXException t, final String action) {
+    private void handle(final HttpServletResponse res, final OXException t, final String action, final Session session) {
         res.setContentType(MIME_TEXT_HTML_CHARSET_UTF8);
 
         final Response resp = new Response();
@@ -566,7 +568,7 @@ public class Attachment extends PermissionServlet {
 
         try {
             writer = new UnsynchronizedStringWriter();
-            ResponseWriter.write(resp, writer);
+            ResponseWriter.write(resp, writer, localeFrom(session));
             res.getWriter().write(substituteJS(writer.toString(), action));
         } catch (final JSONException e) {
             LOG.error("", t);
