@@ -87,7 +87,7 @@ public class Reminder extends DataServlet {
 			} catch (final JSONException e) {
 				LOG.error(e.getMessage(), e);
 	            response.setException(OXJSONExceptionCodes.JSON_BUILD_ERROR.create(e));
-	            writeResponse(response, httpServletResponse);
+	            writeResponse(response, httpServletResponse, session);
 	            return;
 			}
 
@@ -104,7 +104,7 @@ public class Reminder extends DataServlet {
             response.setException(oje);
 		}
 
-		writeResponse(response, httpServletResponse);
+		writeResponse(response, httpServletResponse, session);
 	}
 
 	@Override
@@ -122,7 +122,7 @@ public class Reminder extends DataServlet {
 			} catch (final JSONException e) {
 				LOG.error(e.getMessage(), e);
 	            response.setException(OXJSONExceptionCodes.JSON_BUILD_ERROR.create(e));
-	            writeResponse(response, httpServletResponse);
+	            writeResponse(response, httpServletResponse, session);
 	            return;
 			}
 
@@ -151,7 +151,7 @@ public class Reminder extends DataServlet {
             response.setException(oje);
 		}
 
-		writeResponse(response, httpServletResponse);
+		writeResponse(response, httpServletResponse, session);
 	}
 
 	@Override
