@@ -49,11 +49,19 @@
 
 package com.openexchange.consistency;
 
+import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
+import static com.openexchange.tools.sql.DBUtils.getStatement;
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
+import java.sql.Connection;
+import java.sql.DatabaseMetaData;
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -61,16 +69,20 @@ import java.util.SortedSet;
 import java.util.TreeSet;
 import javax.management.MBeanException;
 import org.apache.commons.logging.Log;
+import com.openexchange.databaseold.Database;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.attach.AttachmentBase;
+import com.openexchange.groupware.attach.AttachmentExceptionCodes;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.infostore.DocumentMetadata;
 import com.openexchange.groupware.infostore.database.impl.DatabaseImpl;
 import com.openexchange.groupware.infostore.database.impl.DocumentMetadataImpl;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.log.LogFactory;
+import com.openexchange.report.internal.Tools;
 import com.openexchange.tools.file.FileStorage;
 import com.openexchange.tools.file.QuotaFileStorage;
+import com.openexchange.tools.sql.DBUtils;
 
 /**
  * Provides the Business Logic for the consistency tool. Concrete subclasses must provide integration to the environment by implementing the
@@ -90,7 +102,7 @@ public abstract class Consistency implements ConsistencyMBean {
             final DoNothingSolver doNothing = new DoNothingSolver();
             final RecordSolver recorder = new RecordSolver();
             final Context ctx = getContext(contextId);
-            checkOneContext(ctx, recorder, recorder, doNothing, getDatabase(), getAttachments(), getFileStorage(ctx));
+            checkOneContext(ctx, recorder, recorder, recorder, doNothing, getDatabase(), getAttachments(), getFileStorage(ctx));
             return recorder.getProblems();
         } catch (final OXException e) {
             LOG.error(e.getMessage(), e);
@@ -166,7 +178,7 @@ public abstract class Consistency implements ConsistencyMBean {
             final DoNothingSolver doNothing = new DoNothingSolver();
             final RecordSolver recorder = new RecordSolver();
             final Context ctx = getContext(contextId);
-            checkOneContext(ctx, doNothing, doNothing, recorder, getDatabase(), getAttachments(), getFileStorage(ctx));
+            checkOneContext(ctx, doNothing, doNothing, doNothing, recorder, getDatabase(), getAttachments(), getFileStorage(ctx));
             return recorder.getProblems();
         } catch (final OXException e) {
             LOG.error(e.getMessage(), e);
@@ -235,12 +247,146 @@ public abstract class Consistency implements ConsistencyMBean {
         }
     }
 
+    /*
+     * FIXME: Here we should call com.openexchange.admin.storage.mysqlStorage.OXContextMySQLStorageCommon.deleteContextFromConfigDB(Connection, int)
+     *        for now I copied the code from there (except the empty schema deletion)
+     */
+    private void deleteContextFromConfigDB(final Connection configCon, final int contextId) throws SQLException {
+        PreparedStatement stmt = null;
+        try {
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Deleting context_server2dbpool mapping for context " + contextId);
+            }
+            // delete context from context_server2db_pool
+            stmt = configCon.prepareStatement("DELETE FROM context_server2db_pool WHERE cid=?");
+            stmt.setInt(1, contextId);
+            stmt.executeUpdate();
+            stmt.close();
+            // tell pool, that database has been removed
+            try {
+                com.openexchange.databaseold.Database.reset(contextId);
+            } catch (final OXException e) {
+                LOG.error(e.getMessage(), e);
+            }
+
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Deleting login2context entries for context " + contextId);
+            }
+            stmt = configCon.prepareStatement("DELETE FROM login2context WHERE cid=?");
+            stmt.setInt(1, contextId);
+            stmt.executeUpdate();
+            stmt.close();
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Deleting context entry for context " + contextId);
+            }
+            stmt = configCon.prepareStatement("DELETE FROM context WHERE cid=?");
+            stmt.setInt(1, contextId);
+            stmt.executeUpdate();
+            stmt.close();
+        } finally {
+            if( null != stmt ) {
+                stmt.close();
+            }
+        }
+    }
+    
+    @Override
+    public List<String> checkOrRepairConfigDB(final boolean repair) throws MBeanException {
+        if( repair ) {
+            LOG.info("Repair inconsistent configdb");
+        } else {
+            LOG.info("List inconsistent configdb");
+        }
+        
+        Connection confCon = null;
+        Connection poolCon = null;
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        List<String> ret = new ArrayList<String>();
+
+        HashMap<String, List<Integer>> schemaMap = new HashMap<String, List<Integer>>();
+        try {
+            final Map<String, Integer> schemaPoolMap = Tools.getAllSchemata(LOG);
+            confCon = Database.get(false);
+            stmt = confCon.prepareStatement("SELECT db_schema,cid FROM context_server2db_pool");
+            rs = stmt.executeQuery();
+            while (rs.next()) {
+                final String schema = rs.getString(1);
+                final Integer ctx = Integer.valueOf(rs.getInt(2));
+                if( schemaMap.containsKey(schema)) {
+                    schemaMap.get(schema).add(ctx);
+                } else {
+                    List<Integer> ctxs = new ArrayList<Integer>();
+                    ctxs.add(ctx);
+                    schemaMap.put(schema, ctxs);
+                }
+            }
+            DBUtils.closeSQLStuff(rs, stmt);
+            stmt = null;
+            for(final String schema : schemaMap.keySet()) {
+                List<Integer> ctxs = schemaMap.get(schema);
+                Integer poolid = schemaPoolMap.get(schema);
+                poolCon = Database.get(poolid.intValue(), schema);
+                String contextids = "";
+                for(final Integer c : ctxs) {
+                    contextids += c + ",";
+                }
+                contextids = contextids.substring(0, contextids.length()-1);
+                stmt = poolCon.prepareStatement("SELECT cid FROM login2user WHERE cid IN (" + contextids + ") GROUP BY cid");
+                rs = stmt.executeQuery();
+                while (rs.next()) {
+                    final Integer ctx = Integer.valueOf(rs.getInt(1));
+                    ctxs.remove(ctx);
+                }
+                if( ctxs.size() > 0 ) {
+                    LOG.info("Schema " + schema + " is broken");
+                    for(final Integer ctx : ctxs) {
+                        if( repair ) {
+                            LOG.info("Deleting inconsistent entry for context " + ctx + " from configdb");
+                            deleteContextFromConfigDB(confCon, ctx.intValue()); 
+                            ret.add("Deleted inconsistent entry for context " + ctx + " from configdb");
+                        } else {
+                            LOG.info("Context " + ctx + " does not exist anymore");
+                            ret.add("Context " + ctx + " does not exist anymore");
+                        }
+                    }
+                }
+                DBUtils.closeSQLStuff(rs, stmt);
+                stmt = null;
+                Database.back(poolid.intValue(), poolCon);
+                poolCon = null;
+            }
+            if ( ret.size() == 0 && repair ) {
+                ret.add("there was nothing to repair");
+            }
+            DBUtils.closeSQLStuff(rs, stmt);
+            stmt = null;
+            return ret;
+        } catch (final SQLException e) {
+            LOG.error(e.getMessage(), e);
+            final Exception wrapMe = new Exception(e.getMessage());
+            throw new MBeanException(wrapMe, e.getMessage());
+        } catch (OXException e) {
+            LOG.error(e.getMessage(), e);
+            final Exception wrapMe = new Exception(e.getMessage());
+            throw new MBeanException(wrapMe, e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(rs, stmt);
+            if (null != confCon) {
+                Database.back(false, confCon);
+            }
+            if (null != poolCon) {
+                Database.back(false, poolCon);
+            }
+        }
+    }
+
     private Map<Integer, List<String>> listMissing(final List<Context> contexts) throws OXException {
         final Map<Integer, List<String>> retval = new HashMap<Integer, List<String>>();
         final DoNothingSolver doNothing = new DoNothingSolver();
         for (final Context ctx : contexts) {
             final RecordSolver recorder = new RecordSolver();
-            checkOneContext(ctx, recorder, recorder, doNothing, getDatabase(), getAttachments(), getFileStorage(ctx));
+            checkOneContext(ctx, recorder, recorder, recorder, doNothing, getDatabase(), getAttachments(), getFileStorage(ctx));
             retval.put(Integer.valueOf(ctx.getContextId()), recorder.getProblems());
         }
         return retval;
@@ -251,7 +397,7 @@ public abstract class Consistency implements ConsistencyMBean {
         final DoNothingSolver doNothing = new DoNothingSolver();
         for (final Context ctx : contexts) {
             final RecordSolver recorder = new RecordSolver();
-            checkOneContext(ctx, doNothing, doNothing, recorder, getDatabase(), getAttachments(), getFileStorage(ctx));
+            checkOneContext(ctx, doNothing, doNothing, doNothing, recorder, getDatabase(), getAttachments(), getFileStorage(ctx));
             retval.put(Integer.valueOf(ctx.getContextId()), recorder.getProblems());
         }
         return retval;
@@ -337,7 +483,7 @@ public abstract class Consistency implements ConsistencyMBean {
 
             final ResolverPolicy resolvers = ResolverPolicy.parse(policy, database, attachments, storage, this);
 
-            checkOneContext(ctx, resolvers.dbsolver, resolvers.attachmentsolver, resolvers.filesolver, database, attachments, storage);
+            checkOneContext(ctx, resolvers.dbsolver, resolvers.attachmentsolver, resolvers.snippetsolver, resolvers.filesolver, database, attachments, storage);
 
             recalculateUsage(storage);
         }
@@ -378,11 +524,11 @@ public abstract class Consistency implements ConsistencyMBean {
         return retval;
     }
 
-    private void checkOneContext(final Context ctx, final ProblemSolver dbSolver, final ProblemSolver attachmentSolver, final ProblemSolver fileSolver, final DatabaseImpl database, final AttachmentBase attach, final FileStorage stor) throws OXException {
+    private void checkOneContext(final Context ctx, final ProblemSolver dbSolver, final ProblemSolver attachmentSolver, final ProblemSolver snippetSolver, final ProblemSolver fileSolver, final DatabaseImpl database, final AttachmentBase attach, final FileStorage stor) throws OXException {
 
         // We believe in the worst case, so lets check the storage first, so
         // that the state file is recreated
-        LOG.info("Checking context " + ctx.getContextId() + ". Using solvers db: " + dbSolver.description() + " attachments: " + attachmentSolver.description() + " files: " + fileSolver.description());
+        LOG.info("Checking context " + ctx.getContextId() + ". Using solvers db: " + dbSolver.description() + " attachments: " + attachmentSolver.description() + " snippets: " + snippetSolver.description() + " files: " + fileSolver.description());
         stor.recreateStateFile();
 
         LOG.info("Listing all files in filestore");
@@ -391,6 +537,8 @@ public abstract class Consistency implements ConsistencyMBean {
         LOG.info("Loading all attachments");
         final SortedSet<String> attachmentset = attach.getAttachmentFileStoreLocationsperContext(ctx);
         LOG.info("Found " + attachmentset.size() + " attachments");
+        final SortedSet<String> snippetset = getSnippetFileStoreLocationsperContext(ctx);
+        LOG.info("Found " + attachmentset.size() + " attachments");
         SortedSet<String> dbfileset;
         try {
             LOG.info("Loading all infostore filestore locations");
@@ -398,6 +546,7 @@ public abstract class Consistency implements ConsistencyMBean {
             LOG.info("Found " + dbfileset.size() + " infostore filepaths");
             final SortedSet<String> joineddbfileset = new TreeSet<String>(dbfileset);
             joineddbfileset.addAll(attachmentset);
+            joineddbfileset.addAll(snippetset);
 
             LOG.info("Found " + joineddbfileset.size() + " filestore ids in total. There are " + filestoreset.size() + " files in the filespool. A difference of " + Math.abs(joineddbfileset.size() - filestoreset.size()));
 
@@ -416,6 +565,14 @@ public abstract class Consistency implements ConsistencyMBean {
                 attachmentSolver.solve(ctx, attachmentset);
             }
 
+            // Build the difference set of the attachment database set, so that the
+            // final attachmentset contains all the members that aren't in the
+            // filestoreset
+            if (diffset(snippetset, filestoreset, "database list of snippet files", "filestore list")) {
+                // implement the solver for deleted dbfiles here
+                snippetSolver.solve(ctx, snippetset);
+            }
+
             // Build the difference set of the filestore set, so that the final
             // filestoreset contains all the members that aren't in the dbfileset or
             // the dbdelfileset
@@ -429,6 +586,44 @@ public abstract class Consistency implements ConsistencyMBean {
         }
     }
 
+    private SortedSet<String> getSnippetFileStoreLocationsperContext(Context ctx) throws OXException {
+        final SortedSet<String> retval = new TreeSet<String>();
+        Connection wcon = null;
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        try {
+            wcon = Database.get(ctx, true);
+            if (tableExists(wcon, "snippet")) {
+                stmt = wcon.prepareStatement("SELECT refId FROM snippet WHERE cid=? AND refType=1");
+                stmt.setInt(1, ctx.getContextId());
+                rs = stmt.executeQuery();
+                while (rs.next()) {
+                    retval.add(rs.getString(1));
+                }
+                DBUtils.closeSQLStuff(rs, stmt);
+                stmt = null;
+            }
+            if (tableExists(wcon, "snippetAttachment")) {
+                stmt = wcon.prepareStatement("SELECT referenceId FROM snippetAttachment WHERE cid=?");
+                stmt.setInt(1, ctx.getContextId());
+                rs = stmt.executeQuery();
+                while (rs.next()) {
+                    retval.add(rs.getString(1));
+                }
+                DBUtils.closeSQLStuff(rs, stmt);
+                stmt = null;
+            }
+        } catch (final SQLException e) {
+            throw AttachmentExceptionCodes.SQL_PROBLEM.create(e, getStatement(stmt));
+        } finally {
+            DBUtils.closeSQLStuff(rs, stmt);
+            if (null != wcon) {
+                Database.back(ctx, true, wcon);
+            }
+        }
+        return retval;
+    }
+
     private void recalculateUsage(final FileStorage storage) {
         try {
             if (storage instanceof QuotaFileStorage) {
@@ -462,11 +657,14 @@ public abstract class Consistency implements ConsistencyMBean {
 
         final ProblemSolver attachmentsolver;
 
+        final ProblemSolver snippetsolver;
+
         final ProblemSolver filesolver;
 
-        public ResolverPolicy(final ProblemSolver dbsolver, final ProblemSolver attachmentsolver, final ProblemSolver filesolver) {
+        public ResolverPolicy(final ProblemSolver dbsolver, final ProblemSolver attachmentsolver, final ProblemSolver snippetsolver, final ProblemSolver filesolver) {
             this.dbsolver = dbsolver;
             this.attachmentsolver = attachmentsolver;
+            this.snippetsolver = snippetsolver;
             this.filesolver = filesolver;
         }
 
@@ -474,6 +672,7 @@ public abstract class Consistency implements ConsistencyMBean {
             final String[] options = list.split("\\s*,\\s*");
             ProblemSolver dbsolver = new DoNothingSolver();
             ProblemSolver attachmentsolver = new DoNothingSolver();
+            ProblemSolver snippetsolver = new DoNothingSolver();
             ProblemSolver filesolver = new DoNothingSolver();
 
             for (final String option : options) {
@@ -499,6 +698,14 @@ public abstract class Consistency implements ConsistencyMBean {
                     } else {
                         attachmentsolver = new DoNothingSolver();
                     }
+                } else if ("missing_file_for_snippet".equals(condition)) {
+                    if ("create_dummy".equals(action)) {
+                        snippetsolver = new CreateDummyFileForSnippet(stor);
+                    } else if ("delete".equals(action)) {
+                        snippetsolver = new DeleteSnippet();
+                    } else {
+                        snippetsolver = new DoNothingSolver();
+                    }
                 } else if ("missing_entry_for_file".equals(condition)) {
                     if ("create_admin_infoitem".equals(action)) {
                         filesolver = new CreateInfoitem(database, stor, consistency);
@@ -510,7 +717,7 @@ public abstract class Consistency implements ConsistencyMBean {
                 }
             }
 
-            return new ResolverPolicy(dbsolver, attachmentsolver, filesolver);
+            return new ResolverPolicy(dbsolver, attachmentsolver, snippetsolver, filesolver);
         }
 
     }
@@ -707,6 +914,72 @@ public abstract class Consistency implements ConsistencyMBean {
 
     }
 
+    private static class CreateDummyFileForSnippet extends CreateDummyFile implements ProblemSolver {
+
+        private static final org.apache.commons.logging.Log LOG1 =
+            com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(CreateDummyFileForSnippet.class));
+
+        public CreateDummyFileForSnippet(final FileStorage storage) {
+            super(storage);
+        }
+
+        @Override
+        public void solve(final Context ctx, final Set<String> problems) throws OXException {
+            /*
+             * Here we operate in two stages. First we create a dummy entry in the filestore. Second we update the Entries in the database
+             */
+            final int size = problems.size();
+            final Iterator<String> it = problems.iterator();
+            for (int k = 0; k < size; k++) {
+                Connection con = null;
+                PreparedStatement stmt = null;
+                try {
+                    con = Database.get(ctx, true);
+                    final String old_identifier = it.next();
+                    // Not recoverable
+                    if (tableExists(con, "snippet")) {
+                        stmt = con.prepareStatement("DELETE FROM snippet WHERE cid=? AND refId=? AND refType=1");
+                        int pos = 0;
+                        stmt.setInt(++pos, ctx.getContextId());
+                        stmt.setString(++pos, old_identifier);
+                        stmt.executeUpdate();
+                        DBUtils.closeSQLStuff(stmt);
+                        stmt = null;
+                    }
+                    // Partly recoverable
+                    if (tableExists(con, "snippetAttachment")) {
+                        final String identifier = createDummyFile();
+                        stmt = con.prepareStatement("UPDATE snippetAttachment SET referenceId=? WHERE cid=? AND referenceId=?");
+                        int pos = 0;
+                        stmt.setString(++pos, identifier);
+                        stmt.setInt(++pos, ctx.getContextId());
+                        stmt.setString(++pos, old_identifier);
+                        stmt.executeUpdate();
+                        DBUtils.closeSQLStuff(stmt);
+                        stmt = null;
+                    }
+                } catch (final SQLException e) {
+                    LOG1.error("", e);
+                } catch (final OXException e) {
+                    LOG1.error("", e);
+                } catch (final RuntimeException e) {
+                    LOG1.error("", e);
+                } finally {
+                    DBUtils.closeSQLStuff(stmt);
+                    if (null != con) {
+                        Database.back(ctx, true, con);
+                    }
+                }
+            }
+        }
+
+        @Override
+        public String description() {
+            return "Create dummy file for snippet";
+        }
+
+    }
+
     private static class RemoveFile implements ProblemSolver {
 
         private static final org.apache.commons.logging.Log LOG1 =
@@ -854,6 +1127,169 @@ public abstract class Consistency implements ConsistencyMBean {
         }
     }
 
+    private static class DeleteSnippet implements ProblemSolver {
+
+        private static final org.apache.commons.logging.Log LOG1 =
+            com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(DeleteSnippet.class));
+
+        public DeleteSnippet() {
+            super();
+        }
+
+        @Override
+        public void solve(final Context ctx, final Set<String> problems) throws OXException {
+            // Now we go through the set an delete each superfluous entry:
+            final Iterator<String> it = problems.iterator();
+            while (it.hasNext()) {
+                Connection con = null;
+                PreparedStatement stmt = null;
+                boolean rollback = false;
+                try {
+                    con = Database.get(ctx, true);
+                    con.setAutoCommit(false);
+                    rollback = true;
+
+                    final int contextId = ctx.getContextId();
+                    final String old_identifier = it.next();
+                    // Not recoverable
+                    if (tableExists(con, "snippet")) {
+                        stmt = con.prepareStatement("DELETE FROM snippet WHERE cid=? AND refId=? AND refType=1");
+                        int pos = 0;
+                        stmt.setInt(++pos, contextId);
+                        stmt.setString(++pos, old_identifier);
+                        stmt.executeUpdate();
+                        DBUtils.closeSQLStuff(stmt);
+                        stmt = null;
+                    }
+                    // Partly recoverable
+                    if (tableExists(con, "snippetAttachment")) {
+                        final List<int[]> pairs = new LinkedList<int[]>();
+                        {
+                            ResultSet rs = null;
+                            try {
+                                stmt = con.prepareStatement("SELECT user, id FROM snippetAttachment WHERE cid=? AND referenceId=?");
+                                int pos = 0;
+                                stmt.setInt(++pos, contextId);
+                                stmt.setString(++pos, old_identifier);
+                                rs = stmt.executeQuery();
+                                while (rs.next()) {
+                                    pairs.add(new int[] { rs.getInt(1), rs.getInt(2) });
+                                }
+                            } finally {
+                                DBUtils.closeSQLStuff(rs, stmt);
+                            }
+                        }
+                        for (final int[] pair : pairs) {
+                            final int userId=pair[0];
+                            final int id=pair[1];
+                            deleteSnippet(id, userId, contextId, con);
+                        }
+                    }
+                    con.commit();
+                    rollback = false;
+                } catch (final SQLException e) {
+                    LOG1.error("", e);
+                } catch (final OXException e) {
+                    LOG1.error("", e);
+                } catch (final RuntimeException e) {
+                    LOG1.error("", e);
+                } finally {
+                    if (rollback) {
+                        DBUtils.rollback(con);
+                    }
+                    DBUtils.closeSQLStuff(stmt);
+                    if (null != con) {
+                        DBUtils.autocommit(con);
+                        Database.back(ctx, true, con);
+                    }
+                }
+            }
+        }
+
+        private void deleteSnippet(final int id, final int userId, final int contextId, final Connection con) {
+            PreparedStatement stmt = null;
+            try {
+                // Delete attachments
+                stmt = con.prepareStatement("DELETE FROM snippetAttachment WHERE cid=? AND user=? AND id=?");
+                int pos = 0;
+                stmt.setLong(++pos, contextId);
+                stmt.setLong(++pos, userId);
+                stmt.setLong(++pos, id);
+                stmt.executeUpdate();
+                closeSQLStuff(stmt);
+                stmt = null;
+                // Delete content
+                stmt = con.prepareStatement("DELETE FROM snippetContent WHERE cid=? AND user=? AND id=?");
+                pos = 0;
+                stmt.setLong(++pos, contextId);
+                stmt.setLong(++pos, userId);
+                stmt.setLong(++pos, id);
+                stmt.executeUpdate();
+                DBUtils.closeSQLStuff(stmt);
+                stmt = null;
+                // Delete JSON object
+                stmt = con.prepareStatement("DELETE FROM snippetMisc WHERE cid=? AND user=? AND id=?");
+                pos = 0;
+                stmt.setLong(++pos, contextId);
+                stmt.setLong(++pos, userId);
+                stmt.setLong(++pos, id);
+                stmt.executeUpdate();
+                DBUtils.closeSQLStuff(stmt);
+                stmt = null;
+                // Delete unnamed properties
+                final int confId;
+                {
+                    ResultSet rs = null;
+                    try {
+                        stmt = con.prepareStatement("SELECT refId FROM snippet WHERE cid=? AND user=? AND id=? AND refType=0");
+                        pos = 0;
+                        stmt.setLong(++pos, contextId);
+                        stmt.setLong(++pos, userId);
+                        stmt.setString(++pos, Integer.toString(id));
+                        rs = stmt.executeQuery();
+                        confId = rs.next() ? Integer.parseInt(rs.getString(1)) : -1;
+                    } finally {
+                        closeSQLStuff(rs, stmt);
+                        stmt = null;
+                        rs = null;
+                    }
+                }
+                if (confId > 0) {
+                    stmt = con.prepareStatement("DELETE FROM genconf_attributes_strings WHERE cid = ? AND id = ?");
+                    pos = 0;
+                    stmt.setLong(++pos, contextId);
+                    stmt.setLong(++pos, confId);
+                    stmt.executeUpdate();
+                    DBUtils.closeSQLStuff(stmt);
+                    stmt = con.prepareStatement("DELETE FROM genconf_attributes_bools WHERE cid = ? AND id = ?");
+                    pos = 0;
+                    stmt.setLong(++pos, contextId);
+                    stmt.setLong(++pos, confId);
+                    stmt.executeUpdate();
+                    DBUtils.closeSQLStuff(stmt);
+                }
+                // Delete snippet
+                stmt = con.prepareStatement("DELETE FROM snippet WHERE cid=? AND user=? AND id=? AND refType=0");
+                pos = 0;
+                stmt.setLong(++pos, contextId);
+                stmt.setLong(++pos, userId);
+                stmt.setString(++pos, Integer.toString(id));
+                stmt.executeUpdate();
+                DBUtils.closeSQLStuff(stmt);
+                stmt = null;
+            } catch (final SQLException e) {
+                LOG1.error("", e);
+            } finally {
+                DBUtils.closeSQLStuff(stmt);
+            }
+        }
+
+        @Override
+        public String description() {
+            return "delete snippet";
+        }
+    }
+
     private static class CreateInfoitem implements ProblemSolver {
 
         private static final org.apache.commons.logging.Log LOG1 =
@@ -937,4 +1373,18 @@ public abstract class Consistency implements ConsistencyMBean {
             return "create infoitem";
         }
     }
+
+    protected static boolean tableExists(final Connection con, final String table) throws SQLException {
+        final DatabaseMetaData metaData = con.getMetaData();
+        ResultSet rs = null;
+        boolean retval = false;
+        try {
+            rs = metaData.getTables(null, null, table, new String[] { "TABLE" });
+            retval = (rs.next() && rs.getString("TABLE_NAME").equals(table));
+        } finally {
+            DBUtils.closeSQLStuff(rs);
+        }
+        return retval;
+    }
+    
 }
