@@ -79,6 +79,7 @@ import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
+import com.openexchange.tools.oxfolder.OXFolderProperties;
 
 /**
  * {@link ContactServiceImpl} - {@link ContactService} implementation.
@@ -160,7 +161,7 @@ public class ContactServiceImpl extends DefaultContactService {
 		 */
 		ContactMapper.getInstance().validateAll(contact);
 		if (contact.containsObjectID() && contact.getObjectID() > 0 && false == Integer.toString(contact.getObjectID()).equals(objectID)) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		}
 		/*
 		 * check source folder
@@ -193,17 +194,17 @@ public class ContactServiceImpl extends DefaultContactService {
 		 */
 		final Contact delta = ContactMapper.getInstance().getDifferences(storedContact, contact);
 		if (delta.containsContextId() && delta.getContextId() > 0) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsObjectID() && delta.getObjectID() > 0) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsUid() && false == Tools.isEmpty(storedContact.getUid())) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsCreatedBy()) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsCreationDate()) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsPrivateFlag() && delta.getPrivateFlag() && storedContact.getModifiedBy() != userID) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		}
 		/*
 		 * prepare update
@@ -225,6 +226,7 @@ public class ContactServiceImpl extends DefaultContactService {
         	}
         }
         Tools.invalidateAddressesIfNeeded(delta);
+        Tools.setFileAsIfNeeded(delta);
 		/*
 		 * pass through to storage
 		 */
@@ -263,6 +265,8 @@ public class ContactServiceImpl extends DefaultContactService {
 		new EventClient(session).modify(storedContact, contact, targetFolder);
 	}
 
+	private static final String GAB = Integer.toString(FolderObject.SYSTEM_LDAP_FOLDER_ID);
+
 	@Override
     protected void doUpdateContact(final Session session, final String folderID, final String objectID, final Contact contact, final Date lastRead) throws OXException {
 		final int userID = session.getUserId();
@@ -273,13 +277,23 @@ public class ContactServiceImpl extends DefaultContactService {
 		 */
 		Check.validateProperties(contact);
 		if (contact.containsObjectID() && contact.getObjectID() > 0 && false == Integer.toString(contact.getObjectID()).equals(objectID)) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		}
 		/*
 		 * check general permissions
 		 */
-		final EffectivePermission permission = Tools.getPermission(contextID, folderID, userID);
-		Check.canWriteOwn(permission, session);
+		EffectivePermission permission = Tools.getPermission(contextID, folderID, userID);
+		try {
+            Check.canWriteOwn(permission, session);
+        } catch (OXException e) {
+            if (!GAB.equals(folderID) || !ContactExceptionCodes.NO_CHANGE_PERMISSION.equals(e) || !OXFolderProperties.isEnableInternalUsersEdit()) {
+                throw e;
+            }
+            OXFolderProperties.updatePermissions(true, contextID);
+            // check again
+            permission = Tools.getPermission(contextID, folderID, userID);
+            Check.canWriteOwn(permission, session);
+        }
 		/*
 		 * check currently stored contact
 		 */
@@ -302,19 +316,19 @@ public class ContactServiceImpl extends DefaultContactService {
 		 */
 		final Contact delta = ContactMapper.getInstance().getDifferences(storedContact, contact);
 		if (delta.containsContextId() && delta.getContextId() > 0) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsObjectID() && delta.getObjectID() > 0) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsUid() && false == Tools.isEmpty(storedContact.getUid())) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsCreatedBy()) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsCreationDate()) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsParentFolderID()) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		} else if (delta.containsPrivateFlag() && delta.getPrivateFlag() && storedContact.getModifiedBy() != userID) {
-			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(objectID), contextID);
+			throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
 		}
 		/*
 		 * prepare update
@@ -335,6 +349,7 @@ public class ContactServiceImpl extends DefaultContactService {
         	}
         }
         Tools.invalidateAddressesIfNeeded(delta);
+        Tools.setFileAsIfNeeded(delta);
 		/*
 		 * pass through to storage
 		 */
@@ -351,6 +366,104 @@ public class ContactServiceImpl extends DefaultContactService {
 		new EventClient(session).modify(storedContact, contact, folder);
 	}
 
+    @Override
+    protected void doUpdateUser(final Session session, final String folderID, final String objectID, final Contact contact, 
+        final Date lastRead) throws OXException {
+        int userID = session.getUserId();
+        int contextID = session.getContextId();
+        ContactStorage storage = Tools.getStorage(session, folderID);
+        /*
+         * check supplied contact
+         */
+        Check.validateProperties(contact);
+        if (contact.containsObjectID() && contact.getObjectID() > 0 && false == Integer.toString(contact.getObjectID()).equals(objectID)) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        }
+        /*
+         * check folder
+         */
+        if (FolderObject.SYSTEM_LDAP_FOLDER_ID != parse(folderID) ||
+            contact.containsParentFolderID() && 0 < contact.getParentFolderID() && 
+            FolderObject.SYSTEM_LDAP_FOLDER_ID != contact.getParentFolderID()) {
+            throw ContactExceptionCodes.NO_ACCESS_PERMISSION.create(FolderObject.SYSTEM_LDAP_FOLDER_ID, contextID, userID);
+        }
+        /*
+         * check currently stored contact
+         */
+        Contact storedContact = storage.get(session, folderID, objectID, ContactField.values());
+        Check.contactNotNull(storedContact, contextID, Tools.parse(objectID));
+        if (storedContact.getCreatedBy() != userID) {
+            if (storedContact.getCreatedBy() == Tools.getContext(contextID).getContextId()) {
+                /*
+                 * take over bugfix for https://bugs.open-xchange.com/show_bug.cgi?id=19128#c9:
+                 * Accepting context admin as a user's contact creator, too, and executing self-healing mechanism
+                 */                
+                contact.setCreatedBy(contact.getInternalUserId());
+            } else {
+                throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+            }
+        }
+        Check.lastModifiedBefore(storedContact, lastRead);
+        Check.folderEquals(storedContact, folderID, contextID);
+        /*
+         * check special GAB permissions
+         */
+        Check.canWriteInGAB(storage, session, folderID, contact);
+        /*
+         * check for not allowed changes
+         */
+        final Contact delta = ContactMapper.getInstance().getDifferences(storedContact, contact);
+        if (delta.containsContextId() && delta.getContextId() > 0) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsObjectID() && delta.getObjectID() > 0) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsUid() && false == Tools.isEmpty(storedContact.getUid())) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsCreatedBy()) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsCreationDate()) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsParentFolderID()) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        } else if (delta.containsPrivateFlag() && delta.getPrivateFlag() && storedContact.getModifiedBy() != userID) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+        }
+        /*
+         * prepare update
+         */
+        final Date now = new Date();
+        delta.setLastModified(now);
+        delta.setModifiedBy(userID);
+        if ((false == storedContact.containsUid() || Tools.isEmpty(storedContact.getUid())) && false == delta.containsUid()) {
+            delta.setUid(UUID.randomUUID().toString());
+        }
+        if (delta.containsImage1()) {
+            delta.setImageLastModified(now);
+            if (null != delta.getImage1()) {
+                delta.setNumberOfImages(1);
+            } else {
+                delta.setNumberOfImages(0);
+                delta.setImageContentType(null);
+            }
+        }
+        Tools.invalidateAddressesIfNeeded(delta);
+        Tools.setFileAsIfNeeded(delta);
+        /*
+         * pass through to storage
+         */
+        storage.update(session, folderID, objectID, delta, lastRead);
+        /*
+         * broadcast event
+         */
+        ContactMapper.getInstance().mergeDifferences(contact, delta);
+        contact.setObjectID(storedContact.getObjectID());
+        contact.setParentFolderID(storedContact.getParentFolderID());
+        for (final ContactStorage contactStorage : Tools.getStorages(session)) {
+            contactStorage.updateReferences(session, contact);
+        }
+        new EventClient(session).modify(storedContact, contact, Tools.getFolder(contextID, folderID));
+    }
+
     @Override
     protected void doDeleteContact(final Session session, final String folderID, final String objectID, final Date lastRead) throws OXException {
         final int userID = session.getUserId();
@@ -389,6 +502,77 @@ public class ContactServiceImpl extends DefaultContactService {
         new EventClient(session).delete(storedContact, folder);
     }
 
+    @Override
+    protected void doDeleteContacts(Session session, String folderID, String[] objectIDs, Date lastRead) throws OXException {
+        final int userID = session.getUserId();
+        final int contextID = session.getContextId();
+        final ContactStorage storage = Tools.getStorage(session, folderID);
+        /*
+         * check folder
+         */
+        FolderObject folder = Tools.getFolder(contextID, folderID);
+        Check.isContactFolder(folder, session);
+        /*
+         * check general permissions
+         */
+        EffectivePermission permission = Tools.getPermission(contextID, folderID, userID);
+        Check.canDeleteOwn(permission, session, folderID);
+        /*
+         * check currently stored contacts
+         */
+        SearchIterator<Contact> contacts = null;
+        List<Contact> storedContacts = new ArrayList<Contact>();
+        try {
+            contacts = storage.list(session, folderID, objectIDs, new ContactField[] { ContactField.CREATED_BY,
+                ContactField.LAST_MODIFIED, ContactField.OBJECT_ID });
+            while (contacts.hasNext()) {
+                Contact storedContact = contacts.next();
+                if (storedContact.getCreatedBy() != userID) {
+                    Check.canDeleteAll(permission, session, folderID);
+                }
+                Check.lastModifiedBefore(storedContact, lastRead);
+                storedContacts.add(storedContact);
+            }
+        } finally {
+            if (null != contacts) {
+                try {
+                    contacts.close();
+                } catch (OXException e) {
+                    LOG.warn("error closing iterator", e);
+                }
+            }            
+        }
+        /*
+         * ensure all contacts were found
+         */
+        for (String objectID : objectIDs) {
+            boolean found = false;
+            for (Contact contact : storedContacts) {
+                if (contact.getObjectID() == parse(objectID)) {
+                    found = true;
+                    break;
+                }
+            }
+            if (false == found) {
+                throw ContactExceptionCodes.CONTACT_NOT_FOUND.create(Integer.valueOf(parse(objectID)), Integer.valueOf(contextID));
+            }
+        }        
+        /*
+         * delete contacts from storage
+         */
+        storage.delete(session, folderID, objectIDs, lastRead);
+        /*
+         * broadcast event
+         */
+        EventClient eventClient = new EventClient(session);
+        for (Contact storedContact : storedContacts) {
+            storedContact.setContextId(contextID);
+            storedContact.setParentFolderID(parse(folderID));
+            storedContact.setObjectID(storedContact.getObjectID());
+            eventClient.delete(storedContact, folder);
+        }
+    }
+
     @Override
     protected void doDeleteContacts(final Session session, final String folderID) throws OXException {
         final int userID = session.getUserId();
@@ -645,8 +829,8 @@ public class ContactServiceImpl extends DefaultContactService {
 		 * limit queried fields when necessary due to permissions
 		 */
 		final EffectivePermission permission = Tools.getPermission(contextID, folderID, currentUserID);
-		final QueryFields queryFields;
-		if (permission.canReadAllObjects() || permission.canReadOwnObjects() && 1 == userIDs.length && currentUserID == userIDs[0]) {
+		QueryFields queryFields;
+		if (permission.canReadAllObjects() || 1 == userIDs.length && currentUserID == userIDs[0]) {
 			// no limitation
 			queryFields = new QueryFields(fields);
 		} else {
@@ -706,7 +890,7 @@ public class ContactServiceImpl extends DefaultContactService {
 		 */
 		final EffectivePermission permission = Tools.getPermission(contextID, folderID, currentUserID);
 		QueryFields queryFields;
-		if (permission.canReadAllObjects() || permission.canReadOwnObjects() && 1 == userIDs.length && currentUserID == userIDs[0]) {
+		if (permission.canReadAllObjects() || 1 == userIDs.length && currentUserID == userIDs[0]) {
 			// no limitation
 			queryFields = new QueryFields(fields);
 		} else {
@@ -723,4 +907,74 @@ public class ContactServiceImpl extends DefaultContactService {
 				queryFields.needsAttachmentInfo(), session, true);
 	}
 
+    @Override
+    protected SearchIterator<Contact> doSearchContactsWithBirthday(Session session, Date from, Date until, List<String> folderIDs, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        int userID = session.getUserId();
+        int contextID = session.getContextId();
+        /*
+         * determine queried storages according to searched folders
+         */
+        Map<ContactStorage, List<String>> queriedStorages = Tools.getStorages(session, 
+            null == folderIDs ? Tools.getVisibleFolders(contextID, userID) : folderIDs);
+        if (null == queriedStorages || 0 == queriedStorages.size()) {
+            throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create("No contact storage found for queried folder IDs");
+        }
+        /*
+         * prepare fields and sort options
+         */
+        QueryFields queryFields = new QueryFields(fields);
+        if (null == sortOptions) {
+            sortOptions = SortOptions.EMPTY;
+        }
+        /*
+         * perform searches
+         */
+        List<SearchIterator<Contact>> searchIterators = new ArrayList<SearchIterator<Contact>>();
+        for (Entry<ContactStorage, List<String>> queriedStorage : queriedStorages.entrySet()) {
+            /*
+             * get results, filtered respecting object permission restrictions, adding attachment info as needed
+             */
+            SearchIterator<Contact> searchIterator = queriedStorage.getKey().searchByBirthday(
+                session, queriedStorage.getValue(), from, until, queryFields.getFields(), sortOptions);
+            searchIterators.add(new ResultIterator(searchIterator, queryFields.needsAttachmentInfo(), session));
+        }
+        return 2 > searchIterators.size() ? searchIterators.get(0) :
+            new ContactMergerator(Tools.getComparator(sortOptions), searchIterators);
+    }
+
+    @Override
+    protected SearchIterator<Contact> doSearchContactsWithAnniversary(Session session, Date from, Date until, List<String> folderIDs, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        int userID = session.getUserId();
+        int contextID = session.getContextId();
+        /*
+         * determine queried storages according to searched folders
+         */
+        Map<ContactStorage, List<String>> queriedStorages = Tools.getStorages(session, 
+            null == folderIDs ? Tools.getVisibleFolders(contextID, userID) : folderIDs);
+        if (null == queriedStorages || 0 == queriedStorages.size()) {
+            throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create("No contact storage found for queried folder IDs");
+        }
+        /*
+         * prepare fields and sort options
+         */
+        QueryFields queryFields = new QueryFields(fields);
+        if (null == sortOptions) {
+            sortOptions = SortOptions.EMPTY;
+        }
+        /*
+         * perform searches
+         */
+        List<SearchIterator<Contact>> searchIterators = new ArrayList<SearchIterator<Contact>>();
+        for (Entry<ContactStorage, List<String>> queriedStorage : queriedStorages.entrySet()) {
+            /*
+             * get results, filtered respecting object permission restrictions, adding attachment info as needed
+             */
+            SearchIterator<Contact> searchIterator = queriedStorage.getKey().searchByAnniversary(
+                session, queriedStorage.getValue(), from, until, queryFields.getFields(), sortOptions);
+            searchIterators.add(new ResultIterator(searchIterator, queryFields.needsAttachmentInfo(), session));
+        }
+        return 2 > searchIterators.size() ? searchIterators.get(0) :
+            new ContactMergerator(Tools.getComparator(sortOptions), searchIterators);
+    }
+
 }
