@@ -51,10 +51,12 @@ package com.openexchange.contact.internal;
 
 import static com.openexchange.contact.internal.Tools.parse;
 import java.util.Date;
+import java.util.List;
 import org.apache.commons.logging.Log;
 import com.openexchange.contact.ContactService;
 import com.openexchange.contact.SortOptions;
 import com.openexchange.exception.OXException;
+import com.openexchange.groupware.contact.ContactExceptionCodes;
 import com.openexchange.groupware.contact.helpers.ContactField;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.ContactSearchObject;
@@ -176,6 +178,16 @@ public abstract class DefaultContactService implements ContactService {
 		return getUsers(session, userIDs, null);
 	}
 	
+    @Override
+    public SearchIterator<Contact> searchContactsWithBirthday(Session session, Date from, Date until, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        return searchContactsWithBirthday(session, null, from, until, fields, sortOptions);
+    }
+
+    @Override
+    public SearchIterator<Contact> searchContactsWithAnniversary(Session session, Date from, Date until, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        return searchContactsWithAnniversary(session, null, from, until, fields, sortOptions);
+    }
+
 	/*
 	 * -----------------------------------------------------------------------------------------------------------------------------------
 	 */
@@ -252,20 +264,35 @@ public abstract class DefaultContactService implements ContactService {
 		this.doCreateContact(session, folderId, contact);
 	}
 
-	@Override
-	public void updateContact(final Session session, final String folderId, final String id, final Contact contact, final Date lastRead) 
-			throws OXException {
-		Check.argNotNull(session, "session");
-		Check.argNotNull(folderId, "folderId");
-		Check.argNotNull(id, "id");
-		Check.argNotNull(lastRead, "lastRead");
-		Check.argNotNull(contact, "contact");
-		if (contact.containsParentFolderID() && contact.getParentFolderID() != parse(folderId)) {
-			this.doUpdateAndMoveContact(session, folderId, Integer.toString(contact.getParentFolderID()), id, contact, lastRead);			
-		} else {
-			this.doUpdateContact(session, folderId, id, contact, lastRead);
-		}
-	}
+    @Override
+    public void updateContact(final Session session, final String folderId, final String id, final Contact contact, final Date lastRead) 
+            throws OXException {
+        Check.argNotNull(session, "session");
+        Check.argNotNull(folderId, "folderId");
+        Check.argNotNull(id, "id");
+        Check.argNotNull(lastRead, "lastRead");
+        Check.argNotNull(contact, "contact");
+        if (contact.containsParentFolderID() && contact.getParentFolderID() != parse(folderId)) {
+            this.doUpdateAndMoveContact(session, folderId, Integer.toString(contact.getParentFolderID()), id, contact, lastRead);           
+        } else {
+            this.doUpdateContact(session, folderId, id, contact, lastRead);
+        }
+    }
+
+    @Override
+    public void updateUser(final Session session, final String folderId, final String id, final Contact contact, final Date lastRead) 
+            throws OXException {
+        Check.argNotNull(session, "session");
+        Check.argNotNull(folderId, "folderId");
+        Check.argNotNull(id, "id");
+        Check.argNotNull(lastRead, "lastRead");
+        Check.argNotNull(contact, "contact");
+        if (contact.containsParentFolderID() && contact.getParentFolderID() != parse(folderId)) {
+            throw ContactExceptionCodes.NO_CHANGE_PERMISSION.create(parse(id), session.getContextId());
+        } else {
+            this.doUpdateUser(session, folderId, id, contact, lastRead);
+        }
+    }
 
     @Override
     public void deleteContact(Session session, String folderId, String id, Date lastRead) throws OXException {
@@ -276,6 +303,15 @@ public abstract class DefaultContactService implements ContactService {
         this.doDeleteContact(session, folderId, id, lastRead);
     }
     
+    @Override
+    public void deleteContacts(Session session, String folderId, String[] ids, Date lastRead) throws OXException {
+        Check.argNotNull(session, "session");
+        Check.argNotNull(folderId, "folderId");
+        Check.argNotNull(ids, "ids");
+        Check.argNotNull(lastRead, "lastRead");
+        this.doDeleteContacts(session, folderId, ids, lastRead);
+    }
+    
     @Override
     public void deleteContacts(Session session, String folderId) throws OXException {
         Check.argNotNull(session, "session");
@@ -333,6 +369,25 @@ public abstract class DefaultContactService implements ContactService {
 		return this.doGetOrganization(session);
     }
 
+    @Override
+    public SearchIterator<Contact> searchContactsWithAnniversary(Session session, List<String> folderIDs, Date from, Date until, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        Check.argNotNull(session, "session");
+        Check.argNotNull(from, "from");
+        Check.argNotNull(until, "until");
+        return doSearchContactsWithAnniversary(session, from, until, folderIDs, fields, sortOptions);
+    }
+    
+    @Override
+    public SearchIterator<Contact> searchContactsWithBirthday(Session session, List<String> folderIDs, Date from, Date until, ContactField[] fields, SortOptions sortOptions) throws OXException {
+        Check.argNotNull(session, "session");
+        Check.argNotNull(from, "from");
+        Check.argNotNull(until, "until");
+        if (from.after(until)) {
+            throw new IllegalArgumentException("'from' must not be after 'until'");
+        }        
+        return doSearchContactsWithBirthday(session, from, until, folderIDs, fields, sortOptions);
+    }
+
 	/*
 	 * -----------------------------------------------------------------------------------------------------------------------------------
 	 */
@@ -342,11 +397,16 @@ public abstract class DefaultContactService implements ContactService {
 	protected abstract void doUpdateAndMoveContact(Session session, String sourceFolderId, String targetFolderId, String objectID, 
 			Contact contact, Date lastRead) throws OXException;
 	
-	protected abstract void doUpdateContact(Session session, String folderID, String objectID, Contact contact, Date lastRead) 
-			throws OXException;
-	
+    protected abstract void doUpdateContact(Session session, String folderID, String objectID, Contact contact, Date lastRead) 
+        throws OXException;
+
+    protected abstract void doUpdateUser(Session session, String folderID, String objectID, Contact contact, Date lastRead) 
+        throws OXException;
+
     protected abstract void doDeleteContact(Session session, String folderID, String objectID, Date lastRead) throws OXException;
     
+    protected abstract void doDeleteContacts(Session session, String folderID, String[] objectIDs, Date lastRead) throws OXException;
+
     protected abstract void doDeleteContacts(Session session, String folderID) throws OXException;
     
 	protected abstract <O> SearchIterator<Contact> doGetContacts(boolean deleted, Session session, String folderID,
@@ -366,4 +426,10 @@ public abstract class DefaultContactService implements ContactService {
 	protected abstract SearchIterator<Contact> doGetUsers(Session session, int[] userIDs, ContactSearchObject contactSearch,
 			ContactField[] fields, SortOptions sortOptions) throws OXException;
 	
+    protected abstract SearchIterator<Contact> doSearchContactsWithBirthday(Session session, Date from, Date until, List<String> folderIDs,
+        ContactField[] fields, SortOptions sortOptions) throws OXException;
+    
+    protected abstract SearchIterator<Contact> doSearchContactsWithAnniversary(Session session, Date from, Date until, List<String> folderIDs,
+        ContactField[] fields, SortOptions sortOptions) throws OXException;
+    
 }
