@@ -396,7 +396,7 @@ public final class Tools {
 	 * @return the folder IDs
 	 * @throws OXException
 	 */
-	private static List<String> getVisibleFolders(final int contextID, final int userID) throws OXException {
+	public static List<String> getVisibleFolders(final int contextID, final int userID) throws OXException {
 		final List<String> folderIDs = new ArrayList<String>();
         final UserConfiguration userConfig = UserConfigurationStorage.getInstance().getUserConfiguration(
         		userID, Tools.getContext(contextID));
@@ -521,6 +521,18 @@ public final class Tools {
 			}
 		}
 	}
+	
+	/**
+	 * Sets the 'file as' attribute to the contact's display name if needed, i.e. the 'display name'-property is set, while the 
+	 * 'file as'-property isn't. 
+	 * 
+	 * @param contact The contact to set the 'file as' for
+	 */
+	public static void setFileAsIfNeeded(final Contact contact) {
+	    if (contact.containsDisplayName() && (false == contact.containsFileAs() || Tools.isEmpty(contact.getFileAs()))) {	        	        
+            contact.setFileAs(contact.getDisplayName());
+	    }
+	}
 
 	/**
 	 * Creates a new {@link ContactSearchObject} containing only the relevant 
