@@ -122,8 +122,9 @@ public abstract class MailFolderStorage implements IMailFolderStorage {
         final MailFolder folder = getFolder(fullName);
         if (isEmpty(newName)) {
             throw MailExceptionCode.INVALID_FOLDER_NAME_EMPTY.create();
-        } else if (newName.indexOf(folder.getSeparator()) != -1) {
-            throw MailExceptionCode.INVALID_FOLDER_NAME.create(String.valueOf(folder.getSeparator()));
+        }
+        if (newName.indexOf(folder.getSeparator()) != -1) {
+            throw MailExceptionCode.INVALID_FOLDER_NAME2.create(newName);
         }
         final String newPath;
         if (MailFolder.DEFAULT_FOLDER_ID.equals(folder.getParentFullname())) {
