@@ -64,6 +64,7 @@ import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.Mail;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
+import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.Converter;
 import com.openexchange.ajax.requesthandler.ResultConverter;
@@ -71,6 +72,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.json.OXJSONWriter;
 import com.openexchange.json.cache.JsonCacheService;
 import com.openexchange.json.cache.JsonCaches;
+import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailListField;
 import com.openexchange.mail.MailServletInterface;
 import com.openexchange.mail.config.MailProperties;
@@ -215,6 +217,7 @@ public final class MailConverter implements ResultConverter, MailActionConstants
         /*
          * Start response
          */
+        final boolean writeThreadAsObjects = AJAXRequestDataTools.parseBoolParameter("konfetti", requestData);
         final boolean containsMultipleFolders = containsMultipleFolders(structure, new HashSet<String>(2));
         jsonWriter.array();
         try {
@@ -223,7 +226,7 @@ public final class MailConverter implements ResultConverter, MailActionConstants
             for (final List<MailMessage> mails : structure.getMails()) {
                 if (mails != null && !mails.isEmpty()) {
                     final JSONObject jo = new JSONObject();
-                    writeThreadSortedMail(mails, jo, writers, headerWriters, containsMultipleFolders, userId, contextId);
+                    writeThreadSortedMail(mails, jo, writers, headerWriters, containsMultipleFolders, writeThreadAsObjects, userId, contextId);
                     jsonWriter.value(jo);
                 }
             }
@@ -277,7 +280,7 @@ public final class MailConverter implements ResultConverter, MailActionConstants
     private static final MailFieldWriter[] WRITER_IDS = MessageWriter.getMailFieldWriter(new MailListField[] {
         MailListField.ID, MailListField.FOLDER_ID });
 
-    private void writeThreadSortedMail(final List<MailMessage> mails, final JSONObject jMail, final MailFieldWriter[] writers, final MailFieldWriter[] headerWriters, final boolean containsMultipleFolders, final int userId, final int contextId) throws OXException, JSONException {
+    private void writeThreadSortedMail(final List<MailMessage> mails, final JSONObject jMail, final MailFieldWriter[] writers, final MailFieldWriter[] headerWriters, final boolean containsMultipleFolders, final boolean writeThreadAsObjects, final int userId, final int contextId) throws OXException, JSONException {
         final MailMessage mail = mails.get(0);
         int accountID = mail.getAccountId();
         for (int j = 0; j < writers.length; j++) {
@@ -291,13 +294,10 @@ public final class MailConverter implements ResultConverter, MailActionConstants
         int unreadCount = 0;
         // Add child nodes
         final JSONArray jChildMessages = new JSONArray();
-        if (writeThreadAsObjects()) {
+        if (writeThreadAsObjects) {
             for (final MailMessage child : mails) {
                 final JSONObject jChild = new JSONObject();
                 accountID = child.getAccountId();
-                /*-
-                 * TODO: Uncomment to write all fields
-                 *
                 for (int j = 0; j < writers.length; j++) {
                     writers[j].writeField(jChild, child, 0, true, accountID, userId, contextId);
                 }
@@ -306,10 +306,13 @@ public final class MailConverter implements ResultConverter, MailActionConstants
                         headerWriters[j].writeField(jChild, child, 0, true, accountID, userId, contextId);
                     }
                 }
-                 */
+                /*-
+                 * 
                 for (final MailFieldWriter w : WRITER_IDS) {
                     w.writeField(jChild, child, 0, true, accountID, userId, contextId);
                 }
+                 * 
+                 */
                 jChildMessages.put(jChild);
                 /*
                  * Count unread messages in this thread structure
@@ -536,8 +539,9 @@ public final class MailConverter implements ResultConverter, MailActionConstants
         }
         final MailServletInterface mailInterface = getMailInterface(requestData, session);
         final List<OXException> warnings = new ArrayList<OXException>(2);
-        final JSONObject jMail =
-            MessageWriter.writeMailMessage(
+        final JSONObject jMail;
+        try {
+            jMail = MessageWriter.writeMailMessage(
                 mail.getAccountId(),
                 mail,
                 displayMode,
@@ -548,6 +552,16 @@ public final class MailConverter implements ResultConverter, MailActionConstants
                 token,
                 ttlMillis,
                 mimeFilter);
+        } catch (final OXException e) {
+            if (MailExceptionCode.MAIL_NOT_FOUND.equals(e)) {
+                LOG.warn(
+                    new StringBuilder("Requested mail could not be found. ").append(
+                        "Most likely this is caused by concurrent access of multiple clients ").append(
+                        "while one performed a delete on affected mail.").toString(),
+                    e);
+            }
+            throw e;
+        }
         if (mail.containsPrevSeen()) {
             try {
                 jMail.put("unseen", wasUnseen);
