@@ -148,6 +148,12 @@ public final class Tools {
      * @throws OXException If check for full names fails
      */
     public static MailAccount checkFullNames(final MailAccount account, final MailAccountStorageService storageService, final Session session) throws OXException {
+        if (MailAccount.DEFAULT_ID == account.getId()) {
+            /*
+             * No check for primary account
+             */
+            return account;
+        }
         final int contextId = session.getContextId();
         final Connection rcon = Database.get(contextId, false);
         try {
@@ -213,7 +219,11 @@ public final class Tools {
                     prefix = getPrefix(accountId, serverSession);
                     tmp = new StringBuilder(prefix);
                 } else {
-                    tmp.setLength(prefix.length());
+                    if (null == tmp) {
+                        tmp = new StringBuilder(prefix);
+                    } else {
+                        tmp.setLength(prefix.length());
+                    }
                 }
                 String name = account.getConfirmedSpam();
                 if (null == name) {
@@ -232,7 +242,11 @@ public final class Tools {
                     prefix = getPrefix(accountId, serverSession);
                     tmp = new StringBuilder(prefix);
                 } else {
-                    tmp.setLength(prefix.length());
+                    if (null == tmp) {
+                        tmp = new StringBuilder(prefix);
+                    } else {
+                        tmp.setLength(prefix.length());
+                    }
                 }
                 String name = account.getDrafts();
                 if (null == name) {
@@ -256,7 +270,11 @@ public final class Tools {
                     prefix = getPrefix(accountId, serverSession);
                     tmp = new StringBuilder(prefix);
                 } else {
-                    tmp.setLength(prefix.length());
+                    if (null == tmp) {
+                        tmp = new StringBuilder(prefix);
+                    } else {
+                        tmp.setLength(prefix.length());
+                    }
                 }
                 String name = account.getSent();
                 if (null == name) {
@@ -280,7 +298,11 @@ public final class Tools {
                     prefix = getPrefix(accountId, serverSession);
                     tmp = new StringBuilder(prefix);
                 } else {
-                    tmp.setLength(prefix.length());
+                    if (null == tmp) {
+                        tmp = new StringBuilder(prefix);
+                    } else {
+                        tmp.setLength(prefix.length());
+                    }
                 }
                 String name = account.getSpam();
                 if (null == name) {
@@ -304,7 +326,11 @@ public final class Tools {
                     prefix = getPrefix(accountId, serverSession);
                     tmp = new StringBuilder(prefix);
                 } else {
-                    tmp.setLength(prefix.length());
+                    if (null == tmp) {
+                        tmp = new StringBuilder(prefix);
+                    } else {
+                        tmp.setLength(prefix.length());
+                    }
                 }
                 String name = account.getTrash();
                 if (null == name) {
@@ -396,13 +422,15 @@ public final class Tools {
 
     private static String getPrefix(final int accountId, final ServerSession session) throws OXException {
         try {
-            final MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> access =
-                MailAccess.getInstance(session, accountId);
-            access.connect(false);
+            MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> access = null;
             try {
+                access = MailAccess.getInstance(session, accountId);
+                access.connect(false);
                 return access.getFolderStorage().getDefaultFolderPrefix();
             } finally {
-                access.close(true);
+                if (null != access) {
+                    access.close(true);
+                }
             }
         } catch (final OXException e) {
             throw new OXException(e);
