@@ -69,19 +69,17 @@ import com.openexchange.cache.impl.FolderQueryCacheManager;
 import com.openexchange.cache.registry.CacheAvailabilityListener;
 import com.openexchange.cache.registry.CacheAvailabilityRegistry;
 import com.openexchange.config.ConfigurationService;
-import com.openexchange.config.PropertyEvent;
-import com.openexchange.config.PropertyListener;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.databaseold.Database;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.cache.CacheFolderStorage;
+import com.openexchange.folderstorage.cache.memory.FolderMapManagement;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.management.ManagementService;
 import com.openexchange.server.Initialization;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.server.services.ServerServiceRegistry;
-import com.openexchange.threadpool.ThreadPoolService;
-import com.openexchange.threadpool.ThreadPools;
-import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 import com.openexchange.tools.oxfolder.memory.ConditionTreeMapManagement;
 import com.openexchange.tools.oxfolder.permissionLoader.PermissionLoaderService;
 import com.openexchange.tools.sql.DBUtils;
@@ -109,15 +107,13 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
      */
     private final AtomicBoolean started = new AtomicBoolean();
 
-    private PropertyListener propertyListener;
-
     private boolean enableDBGrouping = true;
 
     private boolean enableFolderCache = true;
 
     private boolean ignoreSharedAddressbook = false;
 
-    volatile boolean enableInternalUsersEdit = false;
+    volatile boolean enableInternalUsersEdit = true;
 
     private boolean enableSharedFolderCaching = true;
 
@@ -150,17 +146,6 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
             LOG.error("Folder properties cannot be stopped since they have not been started before", new Throwable());
             return;
         }
-        {
-            /*
-             * Remove listener from property
-             */
-            final ConfigurationService configurationService = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
-            if (configurationService != null) {
-                configurationService.removePropertyListener("ENABLE_INTERNAL_USER_EDIT", propertyListener);
-            } else if (LOG.isDebugEnabled()) {
-                LOG.debug("Cannot look-up configuration service to remove property listener.");
-            }
-        }
         final CacheAvailabilityRegistry reg = CacheAvailabilityRegistry.getInstance();
         if (reg != null) {
             reg.unregisterListener(this);
@@ -198,7 +183,6 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
 
     private void reset() {
         enableSharedFolderCaching = true;
-        propertyListener = null;
         enableDBGrouping = true;
         enableFolderCache = true;
         ignoreSharedAddressbook = false;
@@ -246,49 +230,9 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
             ignoreSharedAddressbook = Boolean.parseBoolean(value.trim());
         }
         /*
-         * ENABLE_INTERNAL_USER_EDIT and add listener
+         * ENABLE_INTERNAL_USER_EDIT
          */
-        final org.apache.commons.logging.Log logger = LOG;
-        value = configurationService.getProperty("ENABLE_INTERNAL_USER_EDIT", (propertyListener = new PropertyListener() {
-
-            @Override
-            public void onPropertyChange(final PropertyEvent event) {
-                if (PropertyEvent.Type.CHANGED.equals(event.getType())) {
-                    final boolean enableInternalUsersEditNew = Boolean.parseBoolean(event.getValue());
-                    if (enableInternalUsersEditNew == enableInternalUsersEdit) {
-                        /*
-                         * Changed to same value; ignore
-                         */
-                        return;
-                    }
-                    enableInternalUsersEdit = enableInternalUsersEditNew;
-                } else {
-                    if (!enableInternalUsersEdit) {
-                        /*
-                         * Already set to false
-                         */
-                        return;
-                    }
-                    enableInternalUsersEdit = false;
-                }
-                final ThreadPoolService pool = ThreadPools.getThreadPool();
-                if (null == pool) {
-                    // Run in this thread
-                    updatePermissions(enableInternalUsersEdit);
-                } else {
-                    // Run in separate thread
-                    final Runnable r = new Runnable() {
-
-                        @Override
-                        public void run() {
-                            updatePermissions(enableInternalUsersEdit);
-                        }
-                    };
-                    pool.submit(ThreadPools.task(r), CallerRunsBehavior.getInstance());
-                }
-            }
-
-        }));
+        value = configurationService.getProperty("ENABLE_INTERNAL_USER_EDIT");
         if (null == value) {
             LOG.warn("Missing property ENABLE_INTERNAL_USER_EDIT");
         } else {
@@ -461,6 +405,32 @@ public final class OXFolderProperties implements Initialization, CacheAvailabili
                 LOG.error(e.getMessage(), e);
             }
         }
+        CacheFolderStorage.getInstance().clearAll();
+        FolderMapManagement.getInstance().clear();
+    }
+
+    /**
+     * Updates according to given flag.
+     * 
+     * @param enableInternalUsersEdit The flag
+     * @param contextId The context identifier
+     */
+    public static void updatePermissions(final boolean enableInternalUsersEdit, final int contextId) {
+        /*
+         * Update permissions
+         */
+        updateGABWritePermission(enableInternalUsersEdit, contextId);
+        /*
+         * Clear folder cache to ensure removal of all cached instances of global address book
+         */
+        if (FolderCacheManager.isInitialized()) {
+            try {
+                FolderCacheManager.getInstance().removeFolderObject(FolderObject.SYSTEM_LDAP_FOLDER_ID, ContextStorage.getStorageContext(contextId));
+            } catch (final OXException e) {
+                LOG.error(e.getMessage(), e);
+            }
+        }
+        CacheFolderStorage.getInstance().clearCache(-1, contextId);
     }
 
     private static void updateGABWritePermission(final boolean enableInternalUsersEdit, final int contextId) {
