@@ -228,11 +228,17 @@ final class SessionData {
      * @return <code>true</code> if given user in specified context has an active session; otherwise <code>false</code>
      */
     boolean isUserActive(final int userId, final Context context) {
-        final int contextId = context.getContextId();
-        final Queue<String> queue = volatileUserSessions.get(new UserKey(userId, contextId));
-        if (null != queue && !queue.isEmpty()) {
-            return true;
-        }
+        return isUserActive(userId, context.getContextId());
+    }
+
+    /**
+     * Checks if given user in specified context has an active session kept in session container(s)
+     *
+     * @param userId The user ID
+     * @param contextId The user's context ID
+     * @return <code>true</code> if given user in specified context has an active session; otherwise <code>false</code>
+     */
+    boolean isUserActive(final int userId, final int contextId) {
         // A read-only access to session list
         rlock.lock();
         try {
@@ -582,7 +588,28 @@ final class SessionData {
         return b.booleanValue();
     }
 
-    SessionControl addSession(final SessionImpl session, final boolean noLimit) throws OXException {
+    /**
+     * Adds specified session.
+     * 
+     * @param session The session to add
+     * @param noLimit <code>true</code> to add without respect to limitation; otherwise <code>false</code> to honor limitation
+     * @return The associated {@link SessionControl} instance
+     * @throws OXException If add operation fails
+     */
+    protected SessionControl addSession(final SessionImpl session, final boolean noLimit) throws OXException {
+        return addSession(session, noLimit, false);
+    }
+
+    /**
+     * Adds specified session.
+     * 
+     * @param session The session to add
+     * @param noLimit <code>true</code> to add without respect to limitation; otherwise <code>false</code> to honor limitation
+     * @param addIfAbsent <code>true</code> to perform an add-if-absent operation; otherwise <code>false</code> to fail on duplicate session
+     * @return The associated {@link SessionControl} instance
+     * @throws OXException If add operation fails
+     */
+    protected SessionControl addSession(final SessionImpl session, final boolean noLimit, final boolean addIfAbsent) throws OXException {
         if (!noLimit && countSessions() > maxSessions) {
             throw SessionExceptionCodes.MAX_SESSION_EXCEPTION.create();
         }
@@ -633,7 +660,7 @@ final class SessionData {
             // Adding a session is a writing operation. Other threads requesting a session should be blocked.
             wlock.lock();
             try {
-                control = sessionList.getFirst().put(session);
+                control = sessionList.getFirst().put(session, addIfAbsent);
                 randoms.put(session.getRandomToken(), session.getSessionID());
             } finally {
                 wlock.unlock();
@@ -746,24 +773,23 @@ final class SessionData {
         // Read-only access
         rlock.lock();
         try {
-            for (i = 0; i < sessionList.size(); i++) {
-                final SessionContainer container = sessionList.get(i);
-                if (container.containsSessionId(sessionId)) {
-                    control = container.getSessionById(sessionId);
-                    if (i > 0) {
-                        // Schedule task to put session into first container and remove from latter one. This requires a write lock.
-                        // See bug 16158.
-                        scheduleTask2MoveSession2FirstContainer(sessionId, false);
+            final int size = sessionList.size();
+            for (i = 0; i < size; i++) {
+                    if ((control = sessionList.get(i).getSessionById(sessionId)) != null) {
+                        if (i > 0) {
+                            // Schedule task to put session into first container and remove from latter one. This requires a write lock.
+                            // See bug 16158.
+                            scheduleTask2MoveSession2FirstContainer(sessionId, false);
+                        }
+                        return control;
                     }
-                    break;
-                }
             }
+        } catch (final IndexOutOfBoundsException e) {
+            // For safety
         } finally {
             rlock.unlock();
         }
-        if (null != control) {
-            return control;
-        }
+        // Check long-term container, too
         rlongTermLock.lock();
         try {
             for (final SessionMap longTermMap : longTermList) {
