@@ -49,146 +49,182 @@
 
 package com.openexchange.sessionstorage;
 
+import java.util.Collection;
 import java.util.List;
 import com.openexchange.exception.OXException;
 import com.openexchange.session.Session;
 
 /**
- * {@link SessionStorageService}
- *
+ * {@link SessionStorageService} - A session storage service.
+ * 
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
+ * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface SessionStorageService {
-    
+
     /**
      * Gets the session associated with given session Id
+     * 
      * @param sessionId The session Id
      * @return The session associated with given session Id
      * @throws OXException If no session with given session Id found
      */
     public Session lookupSession(String sessionId) throws OXException;
-    
+
     /**
-     * Adds a new session to session storage
+     * Adds a new session to session storage.
+     * 
      * @param session The session
      * @throws OXException If adding session failed, e.g. duplicate session
      */
     public void addSession(Session session) throws OXException;
-    
+
+    /**
+     * Adds given sessions to session storage if not already contained.
+     * 
+     * @param sessions The sessions
+     * @throws OXException If adding sessions fails for some reason
+     */
+    public void addSessionsIfAbsent(Collection<Session> sessions) throws OXException;
+
+    /**
+     * Adds given session to session storage if not already contained.
+     * 
+     * @param session The session
+     * @throws OXException If adding session fails for some reason
+     * @return <code>true</code> if session could be added; otherwise <code>false</code> if such a session is already present
+     */
+    public boolean addSessionIfAbsent(Session session) throws OXException;
+
     /**
      * Remove the session with given session Id from session storage
+     * 
      * @param sessionId The session Id
      * @throws OXException If no session with given session Id found
      */
     public void removeSession(String sessionId) throws OXException;
-    
+
     /**
      * Remove all sessions for user with given user Id and context Id from session storage
+     * 
      * @param userId The user Id
      * @param contextId The context Id
      * @throws OXException If remove of user sessions failed
      */
     public Session[] removeUserSessions(int userId, int contextId) throws OXException;
-    
+
     /**
      * Remove all sessions from context with given context Id
+     * 
      * @param contextId The context Id
      * @throws OXException If remove of context sessions failed
      */
     public void removeContextSessions(int contextId) throws OXException;
-    
+
     /**
      * Check for active sessions in context with given context Id
+     * 
      * @param contextId The context Id
      * @return <code>true</code> if context has active sessions, otherwise <code>false</code>
      * @throws OXException
      */
     public boolean hasForContext(int contextId) throws OXException;
-    
+
     /**
      * Get all sessions from user with given user Id and context Id
+     * 
      * @param userId The user Id
      * @param contextId The context Id
      * @return Array of all user sessions
      * @throws OXException If there are no sessions from this user
      */
     public Session[] getUserSessions(int userId, int contextId) throws OXException;
-    
+
     /**
      * Get an active session from user with given user Id and context Id
+     * 
      * @param userId The user Id
      * @param contextId The context Id
      * @return An active session from the user
      * @throws OXException If there are no sessions from this user
      */
     public Session getAnyActiveSessionForUser(int userId, int contextId) throws OXException;
-    
+
     /**
      * Get the first found session from user with given user Id and context Id
+     * 
      * @param userId The user Id
      * @param contextId The context Id
      * @return The user session
      * @throws OXException If there are no sessions from this user
      */
     public Session findFirstSessionForUser(int userId, int contextId) throws OXException;
-    
+
     /**
      * Get a list of all stored sessions
+     * 
      * @return A list of all stored sessions
      */
     public List<Session> getSessions();
-    
+
     /**
      * Get the number of active sessions in session storage
+     * 
      * @return The number of active sessions
      */
     public int getNumberOfActiveSessions();
-    
+
     /**
      * Get session identified by given random token
+     * 
      * @param randomToken The random token
      * @param newIP New IP of client
      * @return The session identified by given random token
      * @throws OXException If no session with given random token found
      */
     public Session getSessionByRandomToken(String randomToken, String newIP) throws OXException;
-    
+
     /**
      * Get session identified by given alternative Id
+     * 
      * @param altId The alternative Id
      * @return The session identified by given alternative Id
      * @throws OXException If no session with given alternative Id found
      */
     public Session getSessionByAlternativeId(String altId) throws OXException;
-    
+
     /**
      * Gets the session associated with given session Id
+     * 
      * @param sessionId The session Id
      * @return The session associated with given session Id
      * @throws OXException If no session with given session Id found
      */
     public Session getCachedSession(String sessionId) throws OXException;
-    
-    /**
-     * Clean up session storage
-     * @throws OXException If an error occurs during cleanup
-     */
-    public void cleanUp() throws OXException;
-    
+
     /**
      * Change password in session with given session Id
+     * 
      * @param sessionId The session Id
      * @param newPassword The new password
      * @throws OXException If changing password failed
      */
     public void changePassword(String sessionId, String newPassword) throws OXException;
-    
+
     /**
      * Check authId for duplicates
+     * 
      * @param login Login name to check
      * @param authId AuthId to check
      * @throws OXException If duplicate found
      */
     public void checkAuthId(String login, String authId) throws OXException;
-    
+
+    /**
+     * Clean up session storage
+     * 
+     * @throws OXException On error while clearing
+     */
+    public void cleanUp() throws OXException;
+
 }
