@@ -57,14 +57,20 @@ import com.openexchange.session.PutIfAbsent;
 import com.openexchange.session.Session;
 
 /**
- * {@link StoredSession}
+ * {@link StoredSession} - Represents a session held in session storage.
  * 
  * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
+ * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class StoredSession implements PutIfAbsent, Serializable {
 
     private static final long serialVersionUID = -3414389910481034283L;
 
+    /**
+     * The parameter name for session storage's {@link java.util.concurrent.Future add task}.
+     */
+    //public static final String PARAM_SST_FUTURE = "__sst-future";
+
     private String loginName;
     private String password;
     private int contextId;
@@ -79,7 +85,6 @@ public class StoredSession implements PutIfAbsent, Serializable {
     private String client;
     private String userLogin;
     private final ConcurrentMap<String, Object> parameters;
-    private long lastAccess;
 
     /**
      * Initializes a new {@link StoredSession}.
@@ -121,50 +126,6 @@ public class StoredSession implements PutIfAbsent, Serializable {
                 this.parameters.put(Session.PARAM_CAPABILITIES, parameter);
             }
         }
-        this.lastAccess = System.currentTimeMillis();
-    }
-
-    /**
-     * Initializes a new {@link StoredSession}.
-     */
-    public StoredSession(String sessionId, String loginName, String password, int contextId, int userId, String secret, String login, String randomToken, String localIP, String authId, String hash, String client, Map<String, Object> parameters, long lastAccess) {
-        super();
-        this.sessionId = sessionId;
-        this.loginName = loginName;
-        this.password = password;
-        this.contextId = contextId;
-        this.userId = userId;
-        this.secret = secret;
-        this.login = login;
-        this.randomToken = randomToken;
-        this.localIp = localIP;
-        this.authId = authId;
-        this.hash = hash;
-        this.client = client;
-        this.userLogin = "";
-        this.parameters = new ConcurrentHashMap<String, Object>();
-        // Assign parameters (if not null)
-        if (parameters != null) {
-            Object parameter = parameters.get(Session.PARAM_LOCK);
-            if (null != parameter) {
-                // Unless this is a distributed lock...
-                // this.parameters.put(Session.PARAM_LOCK, parameter);
-            }
-            parameter = parameters.get(Session.PARAM_COUNTER);
-            if (null != parameter) {
-                // Counter is per JVM instance
-                // this.parameters.put(Session.PARAM_COUNTER, parameter);
-            }
-            parameter = parameters.get(Session.PARAM_ALTERNATIVE_ID);
-            if (null != parameter) {
-                this.parameters.put(Session.PARAM_ALTERNATIVE_ID, parameter);
-            }
-            parameter = parameters.get(Session.PARAM_CAPABILITIES);
-            if (null != parameter) {
-                this.parameters.put(Session.PARAM_CAPABILITIES, parameter);
-            }
-        }
-        this.lastAccess = lastAccess;
     }
 
     /**
@@ -207,7 +168,6 @@ public class StoredSession implements PutIfAbsent, Serializable {
         this.sessionId = session.getSessionID();
         this.userId = session.getUserId();
         this.userLogin = session.getUserlogin();
-        this.lastAccess = System.currentTimeMillis();
     }
 
     @Override
@@ -420,12 +380,50 @@ public class StoredSession implements PutIfAbsent, Serializable {
         randomToken = null;
     }
 
-    public long getLastAccess() {
-        return lastAccess;
-    }
-
-    public void setLastAccess(long lastAccess) {
-        this.lastAccess = lastAccess;
+    @Override
+    public String toString() {
+        StringBuilder builder = new StringBuilder(512);
+        final String delim = ", ";
+        builder.append('{');
+        if (loginName != null) {
+            builder.append("loginName=").append(loginName).append(delim);
+        }
+        if (password != null) {
+            builder.append("password=").append("*****").append(delim);
+        }
+        builder.append("contextId=").append(contextId).append(", userId=").append(userId).append(delim);
+        if (sessionId != null) {
+            builder.append("sessionId=").append(sessionId).append(delim);
+        }
+        if (secret != null) {
+            builder.append("secret=").append(secret).append(delim);
+        }
+        if (login != null) {
+            builder.append("login=").append(login).append(delim);
+        }
+        if (randomToken != null) {
+            builder.append("randomToken=").append(randomToken).append(delim);
+        }
+        if (localIp != null) {
+            builder.append("localIp=").append(localIp).append(delim);
+        }
+        if (authId != null) {
+            builder.append("authId=").append(authId).append(delim);
+        }
+        if (hash != null) {
+            builder.append("hash=").append(hash).append(delim);
+        }
+        if (client != null) {
+            builder.append("client=").append(client).append(delim);
+        }
+        if (userLogin != null) {
+            builder.append("userLogin=").append(userLogin).append(delim);
+        }
+        if (parameters != null) {
+            builder.append("parameters=").append(parameters);
+        }
+        builder.append('}');
+        return builder.toString();
     }
 
 }
